'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const BigNumber = require('bignumber.js');

function getCurrencyFormatter(locale, options) {
  return new Intl.NumberFormat(locale ?? "en-US", options);
}
function formatIntlNumber(value, locale, options) {
  const formatter = new Intl.NumberFormat(locale ?? "en-US", {
    ...options,
    style: options?.style ?? "decimal",
    currency: options?.currency ?? "USD",
    minimumFractionDigits: options?.minimumFractionDigits ?? 0,
    maximumFractionDigits: options?.maximumFractionDigits ?? 4
  });
  return formatter.format(value);
}
function formatCurrency(value, locale, options) {
  return formatIntlNumber(value, locale, {
    ...options,
    style: "currency"
  });
}
function safelyFormatNumberWithFallback(formatter, value) {
  try {
    return formatter.format(value.toNumber());
  } catch {
  }
  return value.toString();
}
function clampBigNumber(min, max, value) {
  if (value === "") {
    return "";
  }
  if (new BigNumber(value).gt(max)) {
    return new BigNumber(max).toString();
  }
  if (new BigNumber(value).lt(min)) {
    return new BigNumber(min).toString();
  }
  return value?.toString();
}
function toNumber(value, fallbackValue) {
  if (value == null) return fallbackValue ?? 0;
  if (typeof value === "number") return value;
  if (isNaN(Number(value))) return fallbackValue ?? 0;
  return Number(value);
}
function formatNumeric(value, maximumFractionDigits = 6) {
  return new BigNumber(value).decimalPlaces(maximumFractionDigits).toString();
}

exports.clampBigNumber = clampBigNumber;
exports.formatCurrency = formatCurrency;
exports.formatIntlNumber = formatIntlNumber;
exports.formatNumeric = formatNumeric;
exports.getCurrencyFormatter = getCurrencyFormatter;
exports.safelyFormatNumberWithFallback = safelyFormatNumberWithFallback;
exports.toNumber = toNumber;
