import { globalStyle } from '@vanilla-extract/css';
import { store } from '../models/store.js';
import { DEFAULT_ACCENTS, accents, accentsForeground } from '../styles/tokens/colors.js';
import { ModePreferences } from '../models/system.model.js';
import { isSSR } from './platform.js';

const hexToRgb = (hex) => {
  const channels = hex.replace(
    /^#?([a-f\d])([a-f\d])([a-f\d])$/i,
    (m, r, g, b) => "#" + r + r + g + g + b + b
  ).substring(1).match(/.{2}/g).map((x) => parseInt(x, 16));
  return `rgb(${channels[0]}, ${channels[1]}, ${channels[2]})`;
};
const rgb = (color, alpha) => {
  const rgbColor = color.includes("rgb") ? color : hexToRgb(color);
  const partial = rgbColor.replace("rgb(", "").replace(")", "");
  return alpha ? `rgba(${partial}, ${alpha})` : `rgb(${partial})`;
};
const isDefaultAccent = (accent) => {
  return DEFAULT_ACCENTS.includes(accent);
};
const getAccent = (accent, colorMode) => {
  return isDefaultAccent(accent) ? accents[colorMode ?? "light"][accent] : accent;
};
const getAccentText = (colorMode) => {
  return accentsForeground[colorMode ?? "light"];
};
const getAccentHover = (color) => {
  return rgb(color, "0.075");
};
const mediaQueryColorScheme = (mode) => `(prefers-color-scheme: ${mode})`;
const isValidThemeMode = (mode) => {
  return ModePreferences.includes(mode);
};
const resolveThemeMode = (defaultThemeMode) => {
  const hasHydrated = store.getState()._hasHydrated;
  if (isSSR() || !hasHydrated) {
    return "light";
  }
  const savedTheme = store.getState().themeMode;
  if (isValidThemeMode(defaultThemeMode)) {
    if (defaultThemeMode !== savedTheme) {
      store.getState().setThemeMode(defaultThemeMode);
    }
    return defaultThemeMode;
  }
  if (isValidThemeMode(savedTheme)) {
    return savedTheme;
  }
  store.getState().setThemeMode("system");
  console.log("[resolveThemeMode] using system theme mode");
  return "system";
};
const isPreferLightMode = () => window.matchMedia && window.matchMedia("(prefers-color-scheme: light)").matches;
const isPreferDarkMode = () => window.matchMedia && window.matchMedia("(prefers-color-scheme: dark)").matches;
function childSelectors(styleVariantsSelector, selector, rule) {
  const allSelectors = Array.from(new Set(styleVariantsSelector.split(" ")));
  const targetSelector = allSelectors[allSelectors.length - 1];
  globalStyle(`${targetSelector} ${selector}`, rule);
}

export { childSelectors, getAccent, getAccentHover, getAccentText, isDefaultAccent, isPreferDarkMode, isPreferLightMode, mediaQueryColorScheme, resolveThemeMode, rgb };
