import { ModePreference, ThemeVariant, NumberFormatter } from './system.model';
import { Accent } from '../styles/tokens';
import { OverrideStyleManager } from '../styles/override/override';
import { ThemeDef } from '../styles/override/override.types';
import { StoreApi } from 'zustand/vanilla';
import { PersistOptions } from 'zustand/middleware';
import { WritableDraft } from 'immer';

export declare const STORAGE_NAME = "interchain-ui-store";
export interface UIState {
    themeMode: ModePreference;
    theme: ThemeVariant;
    themeClass: string;
    themeClasses: [string, string];
    themeAccent: Accent;
    customTheme: string | null;
    themeDefs: Array<ThemeDef>;
    overrideStyleManager: OverrideStyleManager;
    _hasHydrated: boolean;
}
export interface UIAction {
    setThemeMode: (mode: ModePreference) => void;
    setTheme: (theme: ThemeVariant, themeClass: string) => void;
    setThemeDefs: (defs: Array<ThemeDef>, defaultTheme?: string) => void;
    setCustomTheme: (customTheme: string) => void;
    setThemeAccent: (accent: Accent) => void;
    setHasHydrated: (hasHydrated: boolean) => void;
}
export interface I18nState {
    formatNumber: NumberFormatter;
}
export interface I18nAction {
    setFormatNumberFn: (fn: NumberFormatter) => void;
}
export interface UIStore extends UIState, UIAction, I18nState, I18nAction {
}
export declare const store: Omit<Omit< StoreApi<UIStore>, "persist"> & {
    persist: {
        setOptions: (options: Partial< PersistOptions<UIStore, {
            themeMode: ModePreference;
        }>>) => void;
        clearStorage: () => void;
        rehydrate: () => Promise<void> | void;
        hasHydrated: () => boolean;
        onHydrate: (fn: (state: UIStore) => void) => () => void;
        onFinishHydration: (fn: (state: UIStore) => void) => () => void;
        getOptions: () => Partial< PersistOptions<UIStore, {
            themeMode: ModePreference;
        }>>;
    };
}, "setState"> & {
    setState(nextStateOrUpdater: UIStore | Partial<UIStore> | ((state: WritableDraft<UIStore>) => void), shouldReplace?: boolean | undefined): void;
};
