import { createStore } from '../node_modules/.pnpm/zustand@4.5.5_@types_react@18.3.7_immer@10.1.1_react@18.3.1/node_modules/zustand/esm/vanilla.js';
import { persist } from '../node_modules/.pnpm/zustand@4.5.5_@types_react@18.3.7_immer@10.1.1_react@18.3.1/node_modules/zustand/esm/middleware.js';
import { immer } from '../node_modules/.pnpm/zustand@4.5.5_@types_react@18.3.7_immer@10.1.1_react@18.3.1/node_modules/zustand/esm/middleware/immer.js';
import { current } from 'immer';
import BigNumber from 'bignumber.js';
import { isPreferDarkMode, isPreferLightMode } from '../helpers/style.js';
import { getCurrencyFormatter, safelyFormatNumberWithFallback } from '../helpers/number.js';
import { lightThemeClass, darkThemeClass } from '../styles/themes.css.js';
import { OverrideStyleManager, assignThemeVars } from '../styles/override/override.js';

const STORAGE_NAME = "interchain-ui-store";
const store = createStore(
  persist(
    immer((set) => ({
      themeMode: null,
      theme: null,
      themeClass: "",
      themeClasses: [lightThemeClass, darkThemeClass],
      themeAccent: "blue",
      // Custom theme contract
      themeDefs: [],
      customTheme: null,
      overrideStyleManager: new OverrideStyleManager("light"),
      _hasHydrated: false,
      setTheme: (newTheme, themeClass) => set((state) => {
        state.theme = newTheme;
        state.themeClass = themeClass;
      }),
      setThemeMode: (newThemeMode) => set((state) => {
        const resolveSystemMode = (themeMode) => {
          if (themeMode === "system") {
            if (isPreferDarkMode()) {
              return ["dark", darkThemeClass];
            }
            if (isPreferLightMode()) {
              return ["light", lightThemeClass];
            }
          } else {
            const themeClass = {
              dark: darkThemeClass,
              light: lightThemeClass
            }[themeMode];
            return [themeMode, themeClass];
          }
        };
        const [resolvedTheme, resolvedClass] = resolveSystemMode(newThemeMode);
        state.overrideStyleManager?.update(null, resolvedTheme);
        state.themeMode = newThemeMode;
        state.theme = resolvedTheme;
        state.themeClass = resolvedClass;
      }),
      setThemeDefs: (defs) => {
        set((state) => {
          state.themeDefs = defs;
        });
      },
      setCustomTheme: (customTheme) => set((state) => {
        state.customTheme = customTheme;
        const currentState = current(state);
        if (customTheme !== null) {
          const customThemeObj = currentState.themeDefs.find(
            (item) => item.name === customTheme
          );
          if (customThemeObj) {
            assignThemeVars(customThemeObj.vars, state.theme);
          }
        }
      }),
      setThemeAccent: (accent) => set((state) => {
        state.themeAccent = accent;
      }),
      formatNumber: (props) => {
        const formatter = getCurrencyFormatter("en-US", {
          currency: "USD",
          style: props.style
        });
        return safelyFormatNumberWithFallback(
          formatter,
          new BigNumber(props.value)
        );
      },
      setFormatNumberFn: (fn) => set((state) => {
        state.formatNumber = fn;
      }),
      setHasHydrated: (hasHydrated) => {
        set({
          _hasHydrated: hasHydrated
        });
      }
    })),
    {
      name: STORAGE_NAME,
      onRehydrateStorage: (state) => {
        return (persistedState) => {
          state.setHasHydrated(true);
          state.setThemeMode(persistedState.themeMode);
        };
      },
      // Only choose to persist theme preference, ignore other state
      partialize: (state) => ({
        themeMode: state.themeMode
      })
    }
  )
);

export { STORAGE_NAME, store };
