'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const dynamic = require('@vanilla-extract/dynamic');
const lodash = require('lodash');
const themes_css = require('../themes.css.cjs');
const button_helper = require('../../ui/button/button.helper.cjs');
const clipboardCopyText_helper = require('../../ui/clipboard-copy-text/clipboard-copy-text.helper.cjs');
const connectModal_helper = require('../../ui/connect-modal/connect-modal.helper.cjs');
const connectModalHead_helper = require('../../ui/connect-modal-head/connect-modal-head.helper.cjs');
const connectModalInstallButton_helper = require('../../ui/connect-modal-install-button/connect-modal-install-button.helper.cjs');
const connectModalQrcode_helper = require('../../ui/connect-modal-qrcode/connect-modal-qrcode.helper.cjs');
const connectModalQrcodeError_helper = require('../../ui/connect-modal-qrcode-error/connect-modal-qrcode-error.helper.cjs');
const connectModalQrcodeSkeleton_helper = require('../../ui/connect-modal-qrcode-skeleton/connect-modal-qrcode-skeleton.helper.cjs');
const connectModalWalletButton_helper = require('../../ui/connect-modal-wallet-button/connect-modal-wallet-button.helper.cjs');

const overrideSchemas = {
  button: button_helper.buttonOverrides,
  "clipboard-copy-text": clipboardCopyText_helper.clipboardCopyTextOverrides,
  "connect-modal": connectModal_helper.connectModalOverrides,
  "connect-modal-head-title": connectModalHead_helper.connectModalHeadTitleOverrides,
  "connect-modal-install-button": connectModalInstallButton_helper.installButtonOverrides,
  "connect-modal-qr-code": connectModalQrcode_helper.connectQRCodeOverrides,
  "connect-modal-qr-code-shadow": connectModalQrcode_helper.connectQRCodeShadowOverrides,
  "connect-modal-qr-code-error": connectModalQrcodeError_helper.connectModalQRCodeErrorOverrides,
  "connect-modal-qr-code-error-button": connectModalQrcodeError_helper.connectModalQRCodeErrorButtonOverrides,
  "connect-modal-qr-code-loading": connectModalQrcodeSkeleton_helper.connectModalQRCodeSkeletonOverrides,
  "connect-modal-wallet-button": connectModalWalletButton_helper.buttonOverrides,
  "connect-modal-wallet-button-label": connectModalWalletButton_helper.buttonLabelOverrides,
  "connect-modal-wallet-button-sublogo": connectModalWalletButton_helper.buttonSublogoOverrides
};
class OverrideStyleManager {
  _overrideMap;
  _theme;
  constructor(theme) {
    this._overrideMap = {};
    this._theme = theme;
  }
  update(overrideMap, theme) {
    if (overrideMap) {
      this._overrideMap = overrideMap;
    }
    if (theme) {
      this._theme = theme;
    }
  }
  applyOverrides(component) {
    const schema = overrideSchemas[component];
    const componentOverrideValue = this._overrideMap[component] ?? {};
    const configByTheme = groupByTheme(componentOverrideValue);
    if (!schema || !configByTheme) {
      return {};
    }
    const config = configByTheme[this._theme];
    const varsMap = {};
    for (const [vanillaCssVar, propertyName] of schema.overrides) {
      const propertyValue = config[propertyName];
      if (!propertyValue) {
        continue;
      }
      varsMap[`${vanillaCssVar}`] = propertyValue;
    }
    return dynamic.assignInlineVars(varsMap);
  }
}
function groupByTheme(config) {
  if (!config) return null;
  const result = {
    light: {},
    dark: {}
  };
  for (const [overrideProperty, propertyConfig] of Object.entries(config)) {
    for (const theme of ["light", "dark"]) {
      result[theme] = {
        ...result[theme],
        [overrideProperty]: propertyConfig[theme]
      };
    }
  }
  return result;
}
function assignThemeVars(customTheme, colorMode) {
  const schemeClass = colorMode === "light" ? themes_css.lightThemeClass : themes_css.darkThemeClass;
  const elements = document.getElementsByClassName(schemeClass);
  const mergedVars = lodash.merge(themes_css.commonVars, customTheme);
  for (let el of elements) {
    dynamic.setElementVars(el, themes_css.themeVars, mergedVars);
  }
}

exports.OverrideStyleManager = OverrideStyleManager;
exports.assignThemeVars = assignThemeVars;
