import autoAnimate, { getTransitionSizes } from '@formkit/auto-animate';
import { isSSR } from '../../helpers/platform.js';

const easing = "cubic-bezier(0.25,0.1,0.25,1)";
function animateLayout(element) {
  if (isSSR()) return;
  autoAnimate(element, (el, action, oldCoords, newCoords) => {
    let keyframes;
    if (action === "add") {
      keyframes = [
        { opacity: 0 },
        { opacity: 0.5, offset: 0.5 },
        { opacity: 1 }
      ];
      return new KeyframeEffect(el, keyframes, {
        duration: 250,
        easing
      });
    }
    if (action === "remove") {
      keyframes = [
        {
          transform: "scale(1)",
          opacity: 1
        },
        {
          transform: "scale(0.97)",
          opacity: 0,
          offset: 0.5
        },
        {
          transform: "scale(0)",
          opacity: 0
        }
      ];
      return new KeyframeEffect(el, keyframes, {
        duration: 150,
        easing
      });
    }
    if (action === "remain") {
      const [widthFrom, widthTo, heightFrom, heightTo] = getTransitionSizes(
        el,
        oldCoords,
        newCoords
      );
      let start = {};
      let mid = {};
      let end = {};
      if (widthFrom !== widthTo) {
        start.width = `${widthFrom}px`;
        end.width = `${widthTo}px`;
      }
      if (heightFrom !== heightTo) {
        start.height = `${heightFrom}px`;
        end.height = `${heightTo}px`;
      }
      start.opacity = 0;
      mid.opacity = 0.5;
      mid.offset = 0.5;
      end.opacity = 1;
      return new KeyframeEffect(el, [start, mid, end], {
        duration: 350,
        easing
      });
    }
  });
}

export { animateLayout };
