import { defineComponent, ref, onMounted, onUnmounted, computed, watch, openBlock, createBlock, unref, normalizeClass, withCtx, createElementVNode, normalizeStyle, createVNode, renderSlot } from 'vue';
import { assignInlineVars } from '@vanilla-extract/dynamic';
import _sfc_main$1 from '../box/box.vue.js';
import _sfc_main$2 from '../avatar-image/avatar-image.vue.js';
import { store } from '../../models/store.js';
import { avatarSize } from './avatar.helper.js';
import { avatarSizeVar, avatar } from './avatar.css.js';

const _hoisted_1 = ["data-loaded", "data-custom-bg"];
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "avatar",
  props: {
    size: { default: "md" },
    rounded: { type: Boolean, default: true },
    showBorder: { type: Boolean, default: void 0 },
    fallbackMode: { default: "initials" },
    borderColor: { default: void 0 },
    backgroundColor: { default: void 0 },
    src: { default: void 0 },
    srcSet: { default: void 0 },
    width: {},
    height: {},
    name: { default: void 0 },
    borderRadius: { default: void 0 },
    loading: { default: void 0 },
    ignoreFallback: { type: Boolean, default: void 0 },
    referrerPolicy: { default: void 0 },
    crossOrigin: { default: void 0 },
    sizes: {},
    onError: { type: Function, default: void 0 },
    onLoad: { type: Function, default: void 0 },
    getInitials: { type: Function, default: void 0 },
    className: { default: void 0 },
    class: {},
    classList: {},
    children: { default: void 0 },
    forwardedRef: {},
    attributes: { default: void 0 },
    showInitials: { type: Boolean }
  },
  setup(__props) {
    const props = __props;
    const internalTheme = ref("light");
    const isLoaded = ref(false);
    const sizeValue = ref(avatarSize(props.size));
    const cleanupRef = ref();
    onMounted(() => {
      internalTheme.value = store.getState().theme;
      cleanupRef.value = store.subscribe((newState) => {
        internalTheme.value = newState.theme;
      });
    });
    onUnmounted(() => {
      if (typeof cleanupRef.value === "function") cleanupRef.value();
    });
    const cssVars = computed(() => {
      return assignInlineVars({
        [avatarSizeVar]: sizeValue.value
      });
    });
    watch(
      () => [props.size],
      () => {
        sizeValue.value = avatarSize(props.size);
      },
      { immediate: true }
    );
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(_sfc_main$1), {
        as: "span",
        display: "inline-flex",
        borderWidth: _ctx.showBorder ? "$sm" : void 0,
        borderColor: _ctx.borderColor,
        borderRadius: _ctx.rounded ? "$full" : "none",
        backgroundColor: _ctx.backgroundColor,
        attributes: _ctx.attributes,
        class: normalizeClass(props.class ?? props.className)
      }, {
        default: withCtx(() => [
          createElementVNode("span", {
            "data-loaded": isLoaded.value,
            "data-custom-bg": !!_ctx.backgroundColor,
            style: normalizeStyle(cssVars.value),
            class: normalizeClass(unref(avatar)[internalTheme.value])
          }, [
            createVNode(unref(_sfc_main$2), {
              src: _ctx.src,
              srcSet: _ctx.srcSet,
              loading: _ctx.loading,
              fallbackMode: _ctx.fallbackMode,
              onLoad: (event) => {
                _ctx.onLoad?.(event);
                isLoaded.value = true;
              },
              width: sizeValue.value,
              height: sizeValue.value,
              onError: (event) => _ctx.onError,
              getInitials: _ctx.getInitials,
              name: _ctx.name,
              borderRadius: _ctx.borderRadius,
              ignoreFallback: _ctx.ignoreFallback,
              crossOrigin: _ctx.crossOrigin,
              referrerPolicy: _ctx.referrerPolicy
            }, null, 8, ["src", "srcSet", "loading", "fallbackMode", "onLoad", "width", "height", "onError", "getInitials", "name", "borderRadius", "ignoreFallback", "crossOrigin", "referrerPolicy"]),
            renderSlot(_ctx.$slots, "default")
          ], 14, _hoisted_1)
        ]),
        _: 3
      }, 8, ["borderWidth", "borderColor", "borderRadius", "backgroundColor", "attributes", "class"]);
    };
  }
});

export { _sfc_main as default };
