'use strict';

Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

const vue = require('vue');
require('@vanilla-extract/dynamic');
const clx = require('clsx');
const icon_vue_vue_type_script_setup_true_lang = require('../icon/icon.vue.cjs');
const box_vue_vue_type_script_setup_true_lang = require('../box/box.vue.cjs');
const spinner_vue_vue_type_script_setup_true_lang = require('../spinner/spinner.vue.cjs');
const store = require('../../models/store.cjs');
const button_helper = require('./button.helper.cjs');
const shared_css = require('../shared/shared.css.cjs');
const button_css = require('./button.css.cjs');

const _sfc_main = /* @__PURE__ */ vue.defineComponent({
  __name: "button",
  props: {
    as: { default: "button" },
    href: {},
    variant: { default: "solid" },
    intent: { default: "primary" },
    size: { default: "md" },
    disabled: { type: Boolean, default: void 0 },
    fluidWidth: { type: Boolean, default: void 0 },
    fluid: { type: Boolean, default: void 0 },
    iconSize: { default: void 0 },
    leftIcon: { default: void 0 },
    rightIcon: { default: void 0 },
    buttonRef: { default: void 0 },
    attributes: { default: void 0 },
    domAttributes: { default: void 0 },
    isLoading: { type: Boolean, default: void 0 },
    spinnerPlacement: { default: "start" },
    onClick: {},
    onDoubleClick: {},
    onMouseDown: {},
    onMouseUp: {},
    onMouseEnter: {},
    onMouseLeave: {},
    onMouseMove: {},
    onMouseOver: {},
    onMouseOut: {},
    onKeyDown: {},
    onKeyUp: {},
    onKeyPress: {},
    onFocus: {},
    onBlur: {},
    onInput: {},
    onChange: {},
    onSubmit: {},
    onReset: {},
    onScroll: {},
    onWheel: {},
    onDragStart: {},
    onDrag: {},
    onDragEnd: {},
    onDragEnter: {},
    onDragLeave: {},
    onDragOver: {},
    onDrop: {},
    onTouchStart: {},
    onTouchMove: {},
    onTouchEnd: {},
    onTouchCancel: {},
    className: { default: void 0 },
    class: {},
    classList: {},
    children: { default: void 0 },
    forwardedRef: {}
  },
  emits: [
    "click",
    "dblclick",
    "mousedown",
    "mouseup",
    "mouseenter",
    "mouseleave",
    "mousemove",
    "mouseover",
    "mouseout",
    "keydown",
    "keyup",
    "keypress",
    "focus",
    "blur",
    "input",
    "change",
    "submit",
    "reset",
    "scroll",
    "wheel",
    "dragstart",
    "drag",
    "dragend",
    "dragenter",
    "dragleave",
    "dragover",
    "drop",
    "touchstart",
    "touchmove",
    "touchend",
    "touchcancel"
  ],
  setup(__props, { emit: __emit }) {
    const emit = __emit;
    const eventMappings = {
      onClick: "click",
      onDoubleClick: "dblclick",
      onMouseDown: "mousedown",
      onMouseUp: "mouseup",
      onMouseEnter: "mouseenter",
      onMouseLeave: "mouseleave",
      onMouseMove: "mousemove",
      onMouseOver: "mouseover",
      onMouseOut: "mouseout",
      onKeyDown: "keydown",
      onKeyUp: "keyup",
      onKeyPress: "keypress",
      onFocus: "focus",
      onBlur: "blur",
      onInput: "input",
      onChange: "change",
      onSubmit: "submit",
      onReset: "reset",
      onScroll: "scroll",
      onWheel: "wheel",
      onDragStart: "dragstart",
      onDrag: "drag",
      onDragEnd: "dragend",
      onDragEnter: "dragenter",
      onDragLeave: "dragleave",
      onDragOver: "dragover",
      onDrop: "drop",
      onTouchStart: "touchstart",
      onTouchMove: "touchmove",
      onTouchEnd: "touchend",
      onTouchCancel: "touchcancel"
    };
    const props = __props;
    const _overrideManager = vue.ref(null);
    const _theme = vue.ref("light");
    const _themeAccent = vue.ref(null);
    const cleanupRef = vue.ref();
    vue.onMounted(() => {
      const uiStore = getStoreState();
      _theme.value = uiStore[0];
      _themeAccent.value = uiStore[1];
      _overrideManager.value = uiStore[2];
      cleanupRef.value = store.store.subscribe((newState, prevState) => {
        _theme.value = newState.theme;
        _themeAccent.value = newState.themeAccent;
        _overrideManager.value = newState.overrideStyleManager;
      });
    });
    vue.onUnmounted(() => {
      if (typeof cleanupRef.value === "function") {
        cleanupRef.value();
      }
    });
    const combinedClassName = vue.computed(() => {
      return clx(
        button_css.buttonSize[props.size],
        button_helper.recipe({
          as: props.as,
          variant: props.variant,
          intent: props.intent ?? "primary",
          isDisabled: props.disabled || props.isLoading,
          theme: getStoreState().theme
        }),
        props.fluidWidth ? shared_css.fullWidth : null,
        props.fluid ? shared_css.fullWidthHeight : null,
        props.class
      );
    });
    const spreadAttributes = vue.computed(() => {
      return Object.assign(
        {
          as: props.as
        },
        {
          attributes: {
            ...props.attributes,
            disabled: props.disabled,
            // style: state.getVars(),
            ...props.domAttributes
          }
        }
      );
    });
    const eventHandlers = vue.computed(() => {
      const handlers = {};
      const eventProps = [
        "onClick",
        "onDoubleClick",
        "onMouseDown",
        "onMouseUp",
        "onMouseEnter",
        "onMouseLeave",
        "onMouseMove",
        "onMouseOver",
        "onMouseOut",
        "onKeyDown",
        "onKeyUp",
        "onKeyPress",
        "onFocus",
        "onBlur",
        "onInput",
        "onChange",
        "onSubmit",
        "onReset",
        "onScroll",
        "onWheel",
        "onDragStart",
        "onDrag",
        "onDragEnd",
        "onDragEnter",
        "onDragLeave",
        "onDragOver",
        "onDrop",
        "onTouchStart",
        "onTouchMove",
        "onTouchEnd",
        "onTouchCancel"
      ];
      eventProps.forEach((eventName) => {
        if (props[eventName]) {
          handlers[eventMappings[eventName]] = (event) => {
            emit(eventMappings[eventName], event);
          };
        }
      });
      return handlers;
    });
    function getStoreState() {
      return {
        theme: store.store.getState().theme,
        themeAccent: store.store.getState().themeAccent,
        overrideStyleManager: store.store.getState().overrideStyleManager
      };
    }
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createBlock(vue.unref(box_vue_vue_type_script_setup_true_lang.default), vue.mergeProps({
        boxRef: _ctx.buttonRef,
        class: combinedClassName.value
      }, {
        ...spreadAttributes.value
      }, vue.toHandlers(eventHandlers.value)), {
        default: vue.withCtx(() => [
          vue.createVNode(vue.unref(spinner_vue_vue_type_script_setup_true_lang.default), {
            size: _ctx.iconSize,
            attributes: {
              display: _ctx.isLoading && _ctx.spinnerPlacement === "start" ? "inline-block" : "none"
            }
          }, null, 8, ["size", "attributes"]),
          vue.createVNode(vue.unref(icon_vue_vue_type_script_setup_true_lang.default), {
            name: _ctx.leftIcon,
            size: _ctx.iconSize,
            attributes: {
              display: !!_ctx.leftIcon && !_ctx.isLoading ? "inline-block" : "none",
              marginRight: !_ctx.$slots.default ? "$0" : "$2"
            }
          }, null, 8, ["name", "size", "attributes"]),
          !_ctx.isLoading ? vue.renderSlot(_ctx.$slots, "default", { key: 0 }) : vue.createCommentVNode("", true),
          vue.createVNode(vue.unref(icon_vue_vue_type_script_setup_true_lang.default), {
            name: _ctx.rightIcon,
            size: _ctx.iconSize,
            attributes: {
              display: !!_ctx.rightIcon && !_ctx.isLoading ? "inline-block" : "none",
              marginLeft: !_ctx.$slots.default ? "$0" : "$2"
            }
          }, null, 8, ["name", "size", "attributes"]),
          vue.createVNode(vue.unref(spinner_vue_vue_type_script_setup_true_lang.default), {
            size: _ctx.iconSize,
            attributes: {
              display: _ctx.isLoading && _ctx.spinnerPlacement === "end" ? "inline-block" : "none"
            }
          }, null, 8, ["size", "attributes"])
        ]),
        _: 3
      }, 16, ["boxRef", "class"]);
    };
  }
});

exports.default = _sfc_main;
