import { defineComponent, ref, onMounted, onUnmounted, computed, openBlock, createBlock, unref, mergeProps, withCtx, createVNode, createCommentVNode, createElementBlock, Fragment, createTextVNode, toDisplayString, renderSlot } from 'vue';
import _sfc_main$3 from '../text/text.vue.js';
import _sfc_main$1 from '../box/box.vue.js';
import _sfc_main$2 from '../icon/icon.vue.js';
import { store } from '../../models/store.js';
import { ALL_ICON_NAMES } from '../icon/icon.types.js';
import { getIntentColors } from './callout.helpers.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "callout",
  props: {
    title: { default: void 0 },
    intent: { default: "none" },
    iconName: { default: void 0 },
    iconRender: { default: void 0 },
    attributes: { default: void 0 },
    className: { default: void 0 },
    class: {},
    classList: {},
    children: { default: void 0 },
    forwardedRef: {}
  },
  setup(__props) {
    const props = __props;
    const internalTheme = ref("light");
    const cleanupRef = ref();
    onMounted(() => {
      internalTheme.value = store.getState().theme;
      cleanupRef.value = store.subscribe((newState, prevState) => {
        internalTheme.value = newState.theme;
      });
    });
    onUnmounted(() => {
      if (typeof cleanupRef.value === "function") cleanupRef.value();
    });
    const colorsProperties = computed(() => {
      return getIntentColors(props.intent, internalTheme.value);
    });
    function isValidIconName() {
      return ALL_ICON_NAMES.includes(props.iconName);
    }
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(_sfc_main$1), mergeProps({
        borderRadius: "$md",
        p: "$6",
        class: props.class ?? props.className
      }, { ...colorsProperties.value, ..._ctx.attributes }), {
        default: withCtx(() => [
          createVNode(unref(_sfc_main$1), {
            display: "flex",
            gap: "$6",
            flexDirection: "column"
          }, {
            default: withCtx(() => [
              createVNode(unref(_sfc_main$1), {
                display: "flex",
                flexWrap: "nowrap",
                gap: "$5"
              }, {
                default: withCtx(() => [
                  !!_ctx.iconName && isValidIconName() ? (openBlock(), createBlock(unref(_sfc_main$2), {
                    key: 0,
                    size: "$3xl",
                    color: "inherit",
                    name: _ctx.iconName
                  }, null, 8, ["name"])) : createCommentVNode("", true),
                  !_ctx.iconName && !isValidIconName() && _ctx.iconRender ? (openBlock(), createElementBlock(Fragment, { key: 1 }, [
                    createTextVNode(toDisplayString(_ctx.iconRender), 1)
                  ], 64)) : createCommentVNode("", true),
                  createVNode(unref(_sfc_main$3), {
                    as: "h5",
                    fontSize: "$md",
                    fontWeight: "$semibold",
                    color: "inherit"
                  }, {
                    default: withCtx(() => [
                      createTextVNode(toDisplayString(_ctx.title), 1)
                    ]),
                    _: 1
                  })
                ]),
                _: 1
              }),
              createVNode(unref(_sfc_main$3), {
                as: "div",
                fontSize: "$sm",
                fontWeight: "$normal",
                color: "inherit"
              }, {
                default: withCtx(() => [
                  renderSlot(_ctx.$slots, "default")
                ]),
                _: 3
              })
            ]),
            _: 3
          })
        ]),
        _: 3
      }, 16, ["class"]);
    };
  }
});

export { _sfc_main as default };
