'use strict';

Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

const vue = require('vue');
const clx = require('clsx');
const copy = require('copy-to-clipboard');
const icon_vue_vue_type_script_setup_true_lang = require('../icon/icon.vue.cjs');
const clipboardCopyText_css = require('./clipboard-copy-text.css.cjs');
const store = require('../../models/store.cjs');
const string = require('../../helpers/string.cjs');
const clipboardCopyText_helper = require('./clipboard-copy-text.helper.cjs');
const text_vue_vue_type_script_setup_true_lang = require('../text/text.vue.cjs');

const _sfc_main = /* @__PURE__ */ vue.defineComponent({
  __name: "clipboard-copy-text",
  props: {
    text: {},
    truncate: {},
    midTruncateLimit: {},
    onCopied: { type: Function },
    className: {},
    class: {},
    classList: {},
    children: {},
    forwardedRef: {}
  },
  setup(__props) {
    const props = __props;
    const idle = vue.ref(true);
    const internalTheme = vue.ref("light");
    const overrideManager = vue.ref(null);
    const cleanupRef = vue.ref();
    vue.onMounted(() => {
      internalTheme.value = store.store.getState().theme;
      overrideManager.value = store.store.getState().overrideStyleManager;
      cleanupRef.value = store.store.subscribe((newState) => {
        internalTheme.value = newState.theme;
        overrideManager.value = newState.overrideStyleManager;
      });
    });
    vue.onUnmounted(() => {
      if (typeof cleanupRef.value === "function") cleanupRef.value();
    });
    function transform(text) {
      if (props.truncate === "middle") {
        const truncateLength = {
          lg: 14,
          md: 16,
          sm: 18
        };
        return string.truncateTextMiddle(
          text,
          truncateLength[props.midTruncateLimit ?? "md"]
        );
      }
      return text;
    }
    function handleOnClick(event) {
      const success = copy(props.text);
      if (success) {
        props.onCopied?.(event);
        idle.value = false;
        setTimeout(() => {
          idle.value = true;
        }, 1e3);
      }
    }
    function getTruncateClass() {
      return clx(clipboardCopyText_css.textStyle, props.truncate === "end" && clipboardCopyText_css.truncateEndStyle);
    }
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createElementBlock("div", {
        onClick: _cache[0] || (_cache[0] = ($event) => handleOnClick($event)),
        style: vue.normalizeStyle(overrideManager.value?.applyOverrides(vue.unref(clipboardCopyText_helper.clipboardCopyTextOverrides).name)),
        class: vue.normalizeClass(vue.unref(clx)(vue.unref(clipboardCopyText_css.containerStyle)[internalTheme.value], _ctx.className))
      }, [
        vue.createVNode(vue.unref(text_vue_vue_type_script_setup_true_lang.default), {
          color: "$textSecondary",
          class: vue.normalizeClass(getTruncateClass())
        }, {
          default: vue.withCtx(() => [
            vue.createTextVNode(vue.toDisplayString(transform(_ctx.text)), 1)
          ]),
          _: 1
        }, 8, ["class"]),
        idle.value ? (vue.openBlock(), vue.createBlock(vue.unref(icon_vue_vue_type_script_setup_true_lang.default), {
          key: 0,
          name: "copy",
          size: "$md",
          class: vue.normalizeClass(vue.unref(clipboardCopyText_css.iconStyle).idle)
        }, null, 8, ["class"])) : (vue.openBlock(), vue.createBlock(vue.unref(icon_vue_vue_type_script_setup_true_lang.default), {
          key: 1,
          name: "checkboxCircle",
          size: "$md",
          class: vue.normalizeClass(vue.unref(clipboardCopyText_css.iconStyle).copied[internalTheme.value])
        }, null, 8, ["class"]))
      ], 6);
    };
  }
});

exports.default = _sfc_main;
