import { defineComponent, ref, onMounted, onUnmounted, watch, openBlock, createBlock, unref, withCtx, createVNode, normalizeClass, createTextVNode, toDisplayString, createElementBlock, Fragment, createCommentVNode, createElementVNode, normalizeStyle } from 'vue';
import anime from 'animejs';
import _sfc_main$4 from '../connect-modal-qrcode-skeleton/connect-modal-qrcode-skeleton.vue.js';
import _sfc_main$1 from '../stack/stack.vue.js';
import _sfc_main$3 from '../box/box.vue.js';
import _sfc_main$2 from '../text/text.vue.js';
import _sfc_main$5 from '../qrcode/qrcode.vue.js';
import _sfc_main$6 from '../connect-modal-qrcode-error/connect-modal-qrcode-error.vue.js';
import { descriptionStyle, qrCodeContainer, qrCodeBgVar, qrCodeFgVar, qrCodeDesc, qrCodeDescContent, qrCodeDescShadow } from './connect-modal-qrcode.css.js';
import { store } from '../../models/store.js';
import { connectQRCodeOverrides, connectQRCodeShadowOverrides } from './connect-modal-qrcode.helper.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "connect-modal-qrcode",
  props: {
    status: { default: void 0 },
    link: { default: void 0 },
    description: { default: void 0 },
    qrCodeSize: { default: 230 },
    errorTitle: { default: void 0 },
    errorDesc: { default: void 0 },
    onRefresh: { type: Function, default: void 0 },
    className: {},
    class: {},
    classList: {},
    children: {},
    forwardedRef: {}
  },
  setup(__props) {
    const displayBlur = ref(false);
    const internalTheme = ref("light");
    const overrideManager = ref(null);
    const measureRef = ref();
    const shadowRef = ref();
    const animationRef = ref();
    const cleanupRef = ref();
    onMounted(() => {
      internalTheme.value = store.getState().theme;
      overrideManager.value = store.getState().overrideStyleManager;
      if (measureRef.value) {
        if (measureRef.value.clientHeight >= 64) {
          displayBlur.value = true;
        } else {
          displayBlur.value = false;
        }
        const scrollHandler = () => {
          const height = Math.abs(
            measureRef.value.scrollHeight - measureRef.value.clientHeight - measureRef.value.scrollTop
          );
          if (height < 1) {
            displayBlur.value = false;
          } else {
            displayBlur.value = true;
          }
        };
        measureRef.value.addEventListener("scroll", scrollHandler);
        const storeUnsub = store.subscribe((newState) => {
          internalTheme.value = newState.theme;
          overrideManager.value = newState.overrideStyleManager;
        });
        cleanupRef.value = () => {
          storeUnsub();
          if (measureRef.value) {
            measureRef.value.removeEventListener("scroll", scrollHandler);
          }
        };
      }
    });
    onUnmounted(() => {
      if (typeof cleanupRef.value === "function") cleanupRef.value();
    });
    watch(
      () => [displayBlur.value, shadowRef.value],
      () => {
        if (!shadowRef.value) return;
        if (shadowRef.value && !animationRef.value) {
          animationRef.value = anime({
            targets: shadowRef.value,
            opacity: [0, 1],
            height: [0, 28],
            delay: 50,
            duration: 250,
            direction: `alternate`,
            loop: false,
            autoplay: false,
            easing: `easeInOutSine`
          });
        }
        if (displayBlur.value) {
          animationRef.value?.restart();
        } else {
          animationRef.value?.reverse();
        }
      },
      { immediate: true }
    );
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(_sfc_main$1), {
        direction: "vertical",
        space: "$0",
        attributes: {
          alignItems: "center"
        }
      }, {
        default: withCtx(() => [
          createVNode(unref(_sfc_main$2), {
            fontWeight: "$medium",
            fontSize: "$md",
            class: normalizeClass(unref(descriptionStyle))
          }, {
            default: withCtx(() => [
              createTextVNode(toDisplayString(_ctx.description), 1)
            ]),
            _: 1
          }, 8, ["class"]),
          _ctx.status === "Pending" ? (openBlock(), createElementBlock(Fragment, { key: 0 }, [
            createVNode(unref(_sfc_main$3), { height: "$4" }),
            createVNode(unref(_sfc_main$4))
          ], 64)) : createCommentVNode("", true),
          _ctx.status === "Done" ? (openBlock(), createElementBlock(Fragment, { key: 1 }, [
            createVNode(unref(_sfc_main$3), { height: "$4" }),
            createElementVNode("div", {
              style: normalizeStyle(overrideManager.value?.applyOverrides(unref(connectQRCodeOverrides).name)),
              class: normalizeClass(unref(qrCodeContainer)[internalTheme.value])
            }, [
              createVNode(unref(_sfc_main$5), {
                level: "L",
                value: _ctx.link,
                size: _ctx.qrCodeSize,
                bgColor: unref(qrCodeBgVar),
                fgColor: unref(qrCodeFgVar),
                includeMargin: false
              }, null, 8, ["value", "size", "bgColor", "fgColor"])
            ], 6)
          ], 64)) : createCommentVNode("", true),
          _ctx.status === "Error" || _ctx.status === "Expired" ? (openBlock(), createElementBlock(Fragment, { key: 2 }, [
            createVNode(unref(_sfc_main$3), { height: "$4" }),
            createVNode(unref(_sfc_main$6), {
              onRefresh: (event) => _ctx.onRefresh?.(),
              qrCodeSize: _ctx.qrCodeSize
            }, null, 8, ["onRefresh", "qrCodeSize"])
          ], 64)) : createCommentVNode("", true),
          !!_ctx.errorTitle ? (openBlock(), createElementBlock(Fragment, { key: 3 }, [
            _ctx.status === "Error" ? (openBlock(), createElementBlock(Fragment, { key: 0 }, [
              createVNode(unref(_sfc_main$3), { height: "$4" }),
              createVNode(unref(_sfc_main$2), {
                as: "p",
                fontWeight: "$medium",
                fontSize: "$md",
                color: "$textDanger",
                attributes: {
                  marginTop: "$2"
                }
              }, {
                default: withCtx(() => [
                  createTextVNode(toDisplayString(_ctx.errorTitle), 1)
                ]),
                _: 1
              })
            ], 64)) : createCommentVNode("", true),
            _ctx.status === "Expired" ? (openBlock(), createElementBlock(Fragment, { key: 1 }, [
              createVNode(unref(_sfc_main$3), { height: "$4" }),
              createVNode(unref(_sfc_main$2), {
                as: "p",
                fontWeight: "$medium",
                fontSize: "$md",
                color: "$textWarning",
                attributes: {
                  marginTop: "$2"
                }
              }, {
                default: withCtx(() => [
                  createTextVNode(toDisplayString(_ctx.errorTitle), 1)
                ]),
                _: 1
              })
            ], 64)) : createCommentVNode("", true)
          ], 64)) : createCommentVNode("", true),
          !!_ctx.errorDesc ? (openBlock(), createElementBlock(Fragment, { key: 4 }, [
            createVNode(unref(_sfc_main$3), { height: "$4" }),
            createElementVNode("div", {
              class: normalizeClass(unref(qrCodeDesc))
            }, [
              createElementVNode("div", {
                ref_key: "measureRef",
                ref: measureRef,
                class: normalizeClass(unref(qrCodeDescContent))
              }, [
                createElementVNode("p", null, toDisplayString(_ctx.errorDesc), 1)
              ], 2),
              createElementVNode("div", {
                ref_key: "shadowRef",
                ref: shadowRef,
                style: normalizeStyle(
                  overrideManager.value?.applyOverrides(unref(connectQRCodeShadowOverrides).name)
                ),
                class: normalizeClass(unref(qrCodeDescShadow)[internalTheme.value])
              }, null, 6)
            ], 2)
          ], 64)) : createCommentVNode("", true)
        ]),
        _: 1
      });
    };
  }
});

export { _sfc_main as default };
