import { defineComponent, ref, onMounted, onUnmounted, openBlock, createElementBlock, normalizeClass, unref, normalizeStyle, createBlock, withCtx, createVNode, createCommentVNode, createElementVNode, createTextVNode, toDisplayString } from 'vue';
import clx from 'clsx';
import { connectButtonStyle, connectButtonVariants, logoVariants, subLogoSquare, buttonTextStyle, buttonTextVariants, subLogoList } from './connect-modal-wallet-button.css.js';
import { store } from '../../models/store.js';
import _sfc_main$1 from '../box/box.vue.js';
import _sfc_main$2 from '../avatar/avatar.vue.js';
import _sfc_main$3 from '../avatar-badge/avatar-badge.vue.js';
import _sfc_main$4 from '../icon/icon.vue.js';
import { buttonOverrides, buttonSublogoOverrides, buttonLabelOverrides } from './connect-modal-wallet-button.helper.js';
import _sfc_main$5 from '../text/text.vue.js';
import { WalletPluginSystem } from '../connect-modal-wallet-list/index.js';

const _hoisted_1 = ["title"];
const _hoisted_2 = ["alt", "src", "width", "height"];
const _hoisted_3 = ["alt", "src"];
const _hoisted_4 = ["alt", "src"];
const _hoisted_5 = ["src", "alt"];
const _hoisted_6 = ["src", "alt"];
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "connect-modal-wallet-button",
  props: {
    variant: {},
    logo: {},
    subLogo: {},
    btmLogo: {},
    name: {},
    prettyName: {},
    badge: {},
    onClick: {},
    className: {},
    class: {},
    classList: {},
    children: {},
    forwardedRef: {}
  },
  setup(__props) {
    const internalTheme = ref("light");
    const overrideManager = ref(null);
    const cleanupRef = ref();
    onMounted(() => {
      internalTheme.value = store.getState().theme;
      overrideManager.value = store.getState().overrideStyleManager;
      cleanupRef.value = store.subscribe((newState) => {
        internalTheme.value = newState.theme;
        overrideManager.value = newState.overrideStyleManager;
      });
    });
    onUnmounted(() => {
      if (typeof cleanupRef.value === "function") cleanupRef.value();
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("button", {
        class: normalizeClass(
          unref(clx)(
            unref(connectButtonStyle)[internalTheme.value],
            unref(connectButtonVariants)({
              variant: _ctx.variant
            })
          )
        ),
        style: normalizeStyle(overrideManager.value?.applyOverrides(unref(buttonOverrides).name)),
        title: _ctx.name,
        onClick: _cache[0] || (_cache[0] = ($event) => _ctx.onClick($event))
      }, [
        !!_ctx.logo ? (openBlock(), createBlock(unref(_sfc_main$1), {
          key: 0,
          as: "span",
          position: "relative",
          display: "block",
          class: normalizeClass(
            unref(clx)(
              unref(logoVariants)({
                variant: _ctx.variant
              })
            )
          )
        }, {
          default: withCtx(() => [
            createVNode(unref(_sfc_main$1), { position: "relative" }, {
              default: withCtx(() => [
                _ctx.logo && !_ctx.btmLogo ? (openBlock(), createElementBlock("img", {
                  key: 0,
                  referrerPolicy: "no-referrer",
                  alt: _ctx.name,
                  src: _ctx.logo,
                  width: _ctx.variant === "square" ? "56px" : "32px",
                  height: _ctx.variant === "square" ? "56px" : "32px",
                  style: {
                    objectFit: "contain"
                  }
                }, null, 8, _hoisted_2)) : createCommentVNode("", true),
                _ctx.btmLogo && _ctx.variant === "list" ? (openBlock(), createBlock(unref(_sfc_main$2), {
                  key: 1,
                  backgroundColor: "transparent",
                  size: "sm",
                  name: _ctx.name,
                  src: _ctx.logo,
                  rounded: false
                }, {
                  default: withCtx(() => [
                    createVNode(unref(_sfc_main$3), {
                      size: "1.2em",
                      borderWidth: "0.1em",
                      attributes: {
                        backgroundColor: internalTheme.value === "dark" ? "$gray300" : "$white"
                      }
                    }, {
                      default: withCtx(() => [
                        createElementVNode("img", {
                          width: "100%",
                          height: "100%",
                          style: {
                            borderRadius: "9999px",
                            objectFit: "contain"
                          },
                          alt: ["MetaMask"].includes(_ctx.btmLogo) ? _ctx.btmLogo : `${_ctx.name} logo`,
                          src: ["MetaMask"].includes(_ctx.btmLogo) ? unref(WalletPluginSystem)[_ctx.btmLogo].logo : _ctx.btmLogo
                        }, null, 8, _hoisted_3)
                      ]),
                      _: 1
                    }, 8, ["attributes"])
                  ]),
                  _: 1
                }, 8, ["name", "src"])) : createCommentVNode("", true),
                _ctx.btmLogo && !_ctx.subLogo && _ctx.variant === "square" ? (openBlock(), createBlock(unref(_sfc_main$2), {
                  key: 2,
                  backgroundColor: "transparent",
                  size: "md",
                  name: _ctx.name,
                  src: _ctx.logo,
                  rounded: false
                }, {
                  default: withCtx(() => [
                    createVNode(unref(_sfc_main$3), {
                      size: "1.2em",
                      borderWidth: "0.1em",
                      attributes: {
                        backgroundColor: internalTheme.value === "dark" ? "$gray300" : "$white"
                      }
                    }, {
                      default: withCtx(() => [
                        createElementVNode("img", {
                          width: "100%",
                          height: "100%",
                          style: {
                            borderRadius: "9999px",
                            objectFit: "contain"
                          },
                          alt: ["MetaMask"].includes(_ctx.btmLogo) ? _ctx.btmLogo : `${_ctx.name} logo`,
                          src: ["MetaMask"].includes(_ctx.btmLogo) ? unref(WalletPluginSystem)[_ctx.btmLogo].logo : _ctx.btmLogo
                        }, null, 8, _hoisted_4)
                      ]),
                      _: 1
                    }, 8, ["attributes"])
                  ]),
                  _: 1
                }, 8, ["name", "src"])) : createCommentVNode("", true)
              ]),
              _: 1
            }),
            _ctx.variant === "square" && typeof _ctx.subLogo === "string" && !_ctx.btmLogo ? (openBlock(), createElementBlock("span", {
              key: 0,
              style: normalizeStyle(
                overrideManager.value?.applyOverrides(unref(buttonSublogoOverrides).name)
              ),
              class: normalizeClass(unref(subLogoSquare)[internalTheme.value])
            }, [
              _ctx.subLogo === "walletConnect" ? (openBlock(), createBlock(unref(_sfc_main$4), {
                key: 0,
                name: "mobileWalletCircle",
                size: "2xl"
              })) : createCommentVNode("", true),
              _ctx.subLogo !== "walletConnect" ? (openBlock(), createElementBlock("img", {
                key: 1,
                width: "24px",
                height: "24px",
                src: _ctx.subLogo,
                alt: `${_ctx.name} sub logo`,
                style: {
                  objectFit: "contain"
                }
              }, null, 8, _hoisted_5)) : createCommentVNode("", true)
            ], 6)) : createCommentVNode("", true)
          ]),
          _: 1
        }, 8, ["class"])) : createCommentVNode("", true),
        createVNode(unref(_sfc_main$1), {
          rawCSS: {
            ...overrideManager.value?.applyOverrides(unref(buttonLabelOverrides).name),
            width: _ctx.variant === "square" ? "calc(80%)" : "auto"
          },
          class: normalizeClass(
            unref(clx)(
              unref(buttonTextStyle)[internalTheme.value],
              unref(buttonTextVariants)({
                variant: _ctx.variant
              })
            )
          )
        }, {
          default: withCtx(() => [
            !_ctx.badge ? (openBlock(), createBlock(unref(_sfc_main$5), {
              key: 0,
              as: "span",
              ellipsis: true,
              textAlign: _ctx.variant === "square" ? "center" : "left",
              attributes: {
                width: "100%",
                display: "inline-block"
              }
            }, {
              default: withCtx(() => [
                createTextVNode(toDisplayString(_ctx.name), 1)
              ]),
              _: 1
            }, 8, ["textAlign"])) : createCommentVNode("", true),
            _ctx.badge ? (openBlock(), createBlock(unref(_sfc_main$5), {
              key: 1,
              as: "p",
              attributes: {
                display: "inline-block",
                position: "relative",
                pr: "$2"
              }
            }, {
              default: withCtx(() => [
                createVNode(unref(_sfc_main$5), {
                  as: "span",
                  ellipsis: true,
                  textAlign: _ctx.variant === "square" ? "center" : "left",
                  attributes: {
                    width: "100%",
                    display: "inline-block"
                  }
                }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString(_ctx.name), 1)
                  ]),
                  _: 1
                }, 8, ["textAlign"]),
                createVNode(unref(_sfc_main$5), {
                  as: "span",
                  fontSize: "$3xs",
                  fontWeight: "$semibold",
                  attributes: {
                    px: "$3",
                    py: "4px",
                    borderRadius: "$md",
                    textTransform: "uppercase",
                    position: "absolute",
                    top: "$-3",
                    left: "$full",
                    color: internalTheme.value === "dark" ? "$gray300" : "$gray800",
                    backgroundColor: internalTheme.value === "dark" ? "$gray600" : "$gray200"
                  }
                }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString(_ctx.badge), 1)
                  ]),
                  _: 1
                }, 8, ["attributes"])
              ]),
              _: 1
            })) : createCommentVNode("", true)
          ]),
          _: 1
        }, 8, ["rawCSS", "class"]),
        _ctx.variant === "list" && typeof _ctx.subLogo === "string" ? (openBlock(), createElementBlock("span", {
          key: 1,
          class: normalizeClass(unref(subLogoList))
        }, [
          _ctx.subLogo === "walletConnect" ? (openBlock(), createBlock(unref(_sfc_main$4), {
            key: 0,
            name: "mobileWallet",
            size: "xl"
          })) : createCommentVNode("", true),
          _ctx.subLogo !== "walletConnect" ? (openBlock(), createElementBlock("img", {
            key: 1,
            width: "20px",
            height: "20px",
            src: _ctx.subLogo,
            alt: `${_ctx.name} sub logo`,
            style: {
              objectFit: "contain"
            }
          }, null, 8, _hoisted_6)) : createCommentVNode("", true)
        ], 2)) : createCommentVNode("", true)
      ], 14, _hoisted_1);
    };
  }
});

export { _sfc_main as default };
