'use strict';

Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

const vue = require('vue');
const store = require('../../../models/store.cjs');

function useTheme() {
  const theme = vue.ref(store.store.getState().theme);
  const themeMode = vue.ref(store.store.getState().themeMode);
  const hasHydrated = vue.ref(store.store.getState()._hasHydrated);
  const themeEvalMode = vue.ref("normal");
  const themeEvalRef = vue.ref(null);
  const forcedModeRef = vue.ref(null);
  const cleanupStore = store.store.subscribe((state) => {
    theme.value = state.theme;
    themeMode.value = state.themeMode;
    hasHydrated.value = state._hasHydrated;
  });
  vue.onUnmounted(() => {
    cleanupStore();
  });
  const setTheme = (mode) => {
    store.store.getState().setThemeMode(mode);
  };
  const toggleColorMode = () => {
    setTheme(store.store.getState().theme === "light" ? "dark" : "light");
  };
  function recursiveGetColorMode(node) {
    if (!node) return;
    let parent = node.parentElement;
    while (parent) {
      if (parent.dataset.interchainColorMode) {
        return parent.dataset.interchainColorMode;
      }
      parent = parent.parentElement;
    }
  }
  function getForceThemeMode() {
    if (themeEvalMode.value === "normal" || !themeEvalRef.value) {
      return theme.value;
    }
    if (forcedModeRef.value) {
      return forcedModeRef.value;
    }
    const forcedMode = recursiveGetColorMode(themeEvalRef.value);
    if (!forcedMode) {
      return theme.value;
    }
    return forcedMode;
  }
  const getThemeRef = (node) => {
    if (node === null) {
      themeEvalRef.value = null;
      return;
    }
    const forcedMode = recursiveGetColorMode(node);
    if (forcedMode === "light" || forcedMode === "dark") {
      themeEvalMode.value = "force";
      forcedModeRef.value = forcedMode;
    }
    themeEvalRef.value = node;
  };
  const computedThemeClass = vue.computed(
    () => themeEvalMode.value === "force" ? getForceThemeMode() === "light" ? store.store.getState().themeClasses[0] : store.store.getState().themeClasses[1] : store.store.getState().themeClass
  );
  const colorMode = vue.computed(
    () => themeEvalMode.value === "force" ? getForceThemeMode() : theme.value
  );
  return {
    hasHydrated,
    theme,
    themeClass: computedThemeClass,
    setTheme,
    colorMode,
    setColorMode: setTheme,
    toggleColorMode,
    getThemeRef
  };
}

exports.default = useTheme;
