'use strict';

Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

const vue = require('vue');
const vue$1 = require('@headlessui/vue');
const modal_css = require('./modal.css.cjs');
const useTheme = require('../hooks/use-theme/use-theme.cjs');

const _sfc_main = /* @__PURE__ */ vue.defineComponent({
  __name: "modal",
  props: {
    isOpen: { type: Boolean, default: void 0 },
    initialOpen: { type: Boolean, default: false },
    onOpen: {},
    onClose: {},
    initialFocusRef: {},
    renderTrigger: {},
    header: {},
    closeOnClickaway: { type: Boolean, default: true },
    preventScroll: { type: Boolean, default: true },
    role: { default: "dialog" },
    root: {},
    className: {},
    themeClassName: {},
    contentStyles: {},
    contentClassName: {},
    backdropClassName: {},
    childrenClassName: {}
  },
  emits: ["update:isOpen"],
  setup(__props, { expose: __expose, emit: __emit }) {
    const props = __props;
    const emit = __emit;
    const defaultRoot = vue.ref(null);
    const isOpen = vue.ref(props.isOpen ?? props.initialOpen);
    const { theme, themeClass, getThemeRef } = useTheme.default();
    const modalContentClass = vue.computed(() => {
      return modal_css.modalContent[theme.value];
    });
    vue.watch(
      () => props.isOpen,
      (newValue) => {
        if (newValue !== void 0) {
          isOpen.value = newValue;
        }
      }
    );
    vue.watch(isOpen, (newValue) => {
      emit("update:isOpen", newValue);
      if (newValue) {
        props.onOpen?.();
      } else {
        props.onClose?.();
      }
    });
    vue.onMounted(() => {
      if (!props.root) {
        defaultRoot.value = document.body;
      }
    });
    const closeModal = () => {
      isOpen.value = false;
    };
    const onCloseButtonClick = () => {
      closeModal();
    };
    __expose({ isOpen });
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createElementBlock(vue.Fragment, null, [
        vue.createVNode(vue.unref(vue$1.TransitionRoot), {
          appear: "",
          show: isOpen.value,
          as: "template"
        }, {
          default: vue.withCtx(() => [
            vue.createVNode(vue.unref(vue$1.Dialog), {
              as: "div",
              class: vue.normalizeClass([modal_css.modalRoot, _ctx.themeClassName, vue.unref(themeClass)]),
              onClose: closeModal,
              role: _ctx.role
            }, {
              default: vue.withCtx(() => [
                vue.createElementVNode("div", {
                  class: vue.normalizeClass(modal_css.modalContainer),
                  ref_key: "getThemeRef",
                  ref: getThemeRef
                }, [
                  vue.createVNode(vue.unref(vue$1.TransitionChild), {
                    as: "template",
                    enter: modal_css.backdropTransitionEnter,
                    "enter-from": modal_css.backdropTransitionEnterFrom,
                    "enter-to": modal_css.backdropTransitionEnterTo,
                    leave: modal_css.backdropTransitionLeave,
                    "leave-from": modal_css.backdropTransitionLeaveFrom,
                    "leave-to": modal_css.backdropTransitionLeaveTo
                  }, {
                    default: vue.withCtx(() => [
                      vue.createElementVNode("div", {
                        class: vue.normalizeClass([modal_css.modalBackdrop, _ctx.backdropClassName, vue.unref(themeClass)]),
                        onClick: _cache[0] || (_cache[0] = ($event) => _ctx.closeOnClickaway ? closeModal : void 0)
                      }, null, 2)
                    ]),
                    _: 1
                  }, 8, ["enter", "enter-from", "enter-to", "leave", "leave-from", "leave-to"]),
                  vue.createElementVNode("div", {
                    class: vue.normalizeClass([modal_css.modalWrapper, vue.unref(themeClass)])
                  }, [
                    vue.createVNode(vue.unref(vue$1.TransitionChild), {
                      as: "template",
                      enter: modal_css.transitionEnter,
                      "enter-from": modal_css.transitionEnterFrom,
                      "enter-to": modal_css.transitionEnterTo,
                      leave: modal_css.transitionLeave,
                      "leave-from": modal_css.transitionLeaveFrom,
                      "leave-to": modal_css.transitionLeaveTo
                    }, {
                      default: vue.withCtx(() => [
                        vue.createVNode(vue.unref(vue$1.DialogPanel), {
                          class: vue.normalizeClass([
                            modal_css.modalPanel,
                            modalContentClass.value,
                            _ctx.className,
                            vue.unref(themeClass)
                          ]),
                          style: vue.normalizeStyle([
                            {
                              "--modal-bg": modal_css.modalBgVar,
                              "--modal-shadow": modal_css.modalShadowVar
                            },
                            _ctx.contentStyles
                          ])
                        }, {
                          default: vue.withCtx(() => [
                            vue.createElementVNode("div", {
                              class: vue.normalizeClass([modal_css.modalContent, _ctx.contentClassName, vue.unref(themeClass)]),
                              "data-modal-part": "content"
                            }, [
                              vue.createElementVNode("div", {
                                class: vue.normalizeClass([modal_css.modalHeader, vue.unref(themeClass)])
                              }, [
                                (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.header), {
                                  closeButtonProps: {
                                    onClick: onCloseButtonClick,
                                    class: [modal_css.modalCloseButton, vue.unref(themeClass)]
                                  }
                                }, null, 8, ["closeButtonProps"]))
                              ], 2),
                              vue.createElementVNode("div", {
                                class: vue.normalizeClass([
                                  modal_css.modalBody,
                                  modal_css.modalChildren,
                                  _ctx.childrenClassName,
                                  vue.unref(themeClass)
                                ]),
                                "data-modal-part": "children"
                              }, [
                                vue.renderSlot(_ctx.$slots, "default")
                              ], 2)
                            ], 2)
                          ]),
                          _: 3
                        }, 8, ["class", "style"])
                      ]),
                      _: 3
                    }, 8, ["enter", "enter-from", "enter-to", "leave", "leave-from", "leave-to"])
                  ], 2)
                ], 2)
              ]),
              _: 3
            }, 8, ["class", "role"])
          ]),
          _: 3
        }, 8, ["show"]),
        vue.renderSlot(_ctx.$slots, "trigger", {
          open: () => isOpen.value = true
        })
      ], 64);
    };
  }
});

exports.default = _sfc_main;
