import { defineComponent, ref, computed, watch, onMounted, openBlock, createElementBlock, Fragment, createVNode, unref, withCtx, normalizeClass, createElementVNode, normalizeStyle, createBlock, resolveDynamicComponent, renderSlot } from 'vue';
import { TransitionRoot, Dialog, TransitionChild, DialogPanel } from '@headlessui/vue';
import { modalContent, modalRoot, modalContainer, backdropTransitionEnter, backdropTransitionEnterFrom, backdropTransitionEnterTo, backdropTransitionLeave, backdropTransitionLeaveFrom, backdropTransitionLeaveTo, modalBackdrop, modalWrapper, transitionEnter, transitionEnterFrom, transitionEnterTo, transitionLeave, transitionLeaveFrom, transitionLeaveTo, modalPanel, modalBgVar, modalShadowVar, modalHeader, modalCloseButton, modalBody, modalChildren } from './modal.css.js';
import useTheme from '../hooks/use-theme/use-theme.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "modal",
  props: {
    isOpen: { type: Boolean, default: void 0 },
    initialOpen: { type: Boolean, default: false },
    onOpen: {},
    onClose: {},
    initialFocusRef: {},
    renderTrigger: {},
    header: {},
    closeOnClickaway: { type: Boolean, default: true },
    preventScroll: { type: Boolean, default: true },
    role: { default: "dialog" },
    root: {},
    className: {},
    themeClassName: {},
    contentStyles: {},
    contentClassName: {},
    backdropClassName: {},
    childrenClassName: {}
  },
  emits: ["update:isOpen"],
  setup(__props, { expose: __expose, emit: __emit }) {
    const props = __props;
    const emit = __emit;
    const defaultRoot = ref(null);
    const isOpen = ref(props.isOpen ?? props.initialOpen);
    const { theme, themeClass, getThemeRef } = useTheme();
    const modalContentClass = computed(() => {
      return modalContent[theme.value];
    });
    watch(
      () => props.isOpen,
      (newValue) => {
        if (newValue !== void 0) {
          isOpen.value = newValue;
        }
      }
    );
    watch(isOpen, (newValue) => {
      emit("update:isOpen", newValue);
      if (newValue) {
        props.onOpen?.();
      } else {
        props.onClose?.();
      }
    });
    onMounted(() => {
      if (!props.root) {
        defaultRoot.value = document.body;
      }
    });
    const closeModal = () => {
      isOpen.value = false;
    };
    const onCloseButtonClick = () => {
      closeModal();
    };
    __expose({ isOpen });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment, null, [
        createVNode(unref(TransitionRoot), {
          appear: "",
          show: isOpen.value,
          as: "template"
        }, {
          default: withCtx(() => [
            createVNode(unref(Dialog), {
              as: "div",
              class: normalizeClass([modalRoot, _ctx.themeClassName, unref(themeClass)]),
              onClose: closeModal,
              role: _ctx.role
            }, {
              default: withCtx(() => [
                createElementVNode("div", {
                  class: normalizeClass(modalContainer),
                  ref_key: "getThemeRef",
                  ref: getThemeRef
                }, [
                  createVNode(unref(TransitionChild), {
                    as: "template",
                    enter: backdropTransitionEnter,
                    "enter-from": backdropTransitionEnterFrom,
                    "enter-to": backdropTransitionEnterTo,
                    leave: backdropTransitionLeave,
                    "leave-from": backdropTransitionLeaveFrom,
                    "leave-to": backdropTransitionLeaveTo
                  }, {
                    default: withCtx(() => [
                      createElementVNode("div", {
                        class: normalizeClass([modalBackdrop, _ctx.backdropClassName, unref(themeClass)]),
                        onClick: _cache[0] || (_cache[0] = ($event) => _ctx.closeOnClickaway ? closeModal : void 0)
                      }, null, 2)
                    ]),
                    _: 1
                  }, 8, ["enter", "enter-from", "enter-to", "leave", "leave-from", "leave-to"]),
                  createElementVNode("div", {
                    class: normalizeClass([modalWrapper, unref(themeClass)])
                  }, [
                    createVNode(unref(TransitionChild), {
                      as: "template",
                      enter: transitionEnter,
                      "enter-from": transitionEnterFrom,
                      "enter-to": transitionEnterTo,
                      leave: transitionLeave,
                      "leave-from": transitionLeaveFrom,
                      "leave-to": transitionLeaveTo
                    }, {
                      default: withCtx(() => [
                        createVNode(unref(DialogPanel), {
                          class: normalizeClass([
                            modalPanel,
                            modalContentClass.value,
                            _ctx.className,
                            unref(themeClass)
                          ]),
                          style: normalizeStyle([
                            {
                              "--modal-bg": modalBgVar,
                              "--modal-shadow": modalShadowVar
                            },
                            _ctx.contentStyles
                          ])
                        }, {
                          default: withCtx(() => [
                            createElementVNode("div", {
                              class: normalizeClass([modalContent, _ctx.contentClassName, unref(themeClass)]),
                              "data-modal-part": "content"
                            }, [
                              createElementVNode("div", {
                                class: normalizeClass([modalHeader, unref(themeClass)])
                              }, [
                                (openBlock(), createBlock(resolveDynamicComponent(_ctx.header), {
                                  closeButtonProps: {
                                    onClick: onCloseButtonClick,
                                    class: [modalCloseButton, unref(themeClass)]
                                  }
                                }, null, 8, ["closeButtonProps"]))
                              ], 2),
                              createElementVNode("div", {
                                class: normalizeClass([
                                  modalBody,
                                  modalChildren,
                                  _ctx.childrenClassName,
                                  unref(themeClass)
                                ]),
                                "data-modal-part": "children"
                              }, [
                                renderSlot(_ctx.$slots, "default")
                              ], 2)
                            ], 2)
                          ]),
                          _: 3
                        }, 8, ["class", "style"])
                      ]),
                      _: 3
                    }, 8, ["enter", "enter-from", "enter-to", "leave", "leave-from", "leave-to"])
                  ], 2)
                ], 2)
              ]),
              _: 3
            }, 8, ["class", "role"])
          ]),
          _: 3
        }, 8, ["show"]),
        renderSlot(_ctx.$slots, "trigger", {
          open: () => isOpen.value = true
        })
      ], 64);
    };
  }
});

export { _sfc_main as default };
