'use strict';

Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

const vue = require('vue');
const qrcodegen = require('./qrcodegen/qrcodegen.cjs');
const qrcode_types = require('./qrcode.types.cjs');
const qrcode_helpers = require('./qrcode.helpers.cjs');

const _hoisted_1 = ["height", "width", "viewBox"];
const _hoisted_2 = { key: 0 };
const _hoisted_3 = ["fill", "d"];
const _hoisted_4 = ["fill", "d"];
const _hoisted_5 = ["href", "height", "width", "x", "y"];
const _sfc_main = /* @__PURE__ */ vue.defineComponent({
  __name: "qrcode",
  props: {
    value: { default: void 0 },
    size: { default: qrcode_types.DEFAULT_SIZE },
    level: { default: qrcode_types.DEFAULT_LEVEL },
    bgColor: { default: qrcode_types.DEFAULT_BGCOLOR },
    fgColor: { default: qrcode_types.DEFAULT_FGCOLOR },
    includeMargin: { type: Boolean, default: qrcode_types.DEFAULT_INCLUDEMARGIN },
    marginSize: { default: void 0 },
    imageSettings: { default: void 0 },
    title: { default: void 0 },
    className: { default: void 0 },
    class: {},
    classList: {},
    children: {},
    forwardedRef: {}
  },
  setup(__props) {
    const props = __props;
    const available = vue.ref(false);
    const cells = vue.ref(null);
    const calculatedImageSettings = vue.ref(null);
    const margin = vue.ref(null);
    const fgPath = vue.ref(null);
    vue.onMounted(() => {
      cells.value = genCells();
    });
    vue.watch(
      () => [props.imageSettings, calculatedImageSettings.value],
      () => {
        if (props.imageSettings != null && calculatedImageSettings.value != null) {
          if (calculatedImageSettings.value.excavation != null) {
            cells.value = qrcode_helpers.excavateModules(
              cells.value,
              calculatedImageSettings.value.excavation
            );
          }
          if (!available.value) {
            available.value = true;
          }
        }
      },
      { immediate: true }
    );
    vue.watch(
      () => [
        props.size,
        props.imageSettings,
        props.includeMargin,
        props.marginSize,
        cells.value
      ],
      () => {
        const newMargin = qrcode_helpers.getMarginSize(props.includeMargin, props.marginSize);
        margin.value = newMargin;
        calculatedImageSettings.value = qrcode_helpers.getImageSettings(
          cells.value,
          props.size,
          newMargin,
          props.imageSettings
        );
        fgPath.value = generateNewPath(newMargin);
      },
      { immediate: true }
    );
    function generateNewPath(newMargin) {
      return qrcode_helpers.generatePath(cells.value ?? [], newMargin);
    }
    function genCells() {
      return qrcodegen.default.QrCode.encodeText(
        props.value,
        qrcode_types.ERROR_LEVEL_MAP[props.level]
      ).getModules();
    }
    function numCells() {
      return (cells.value?.length ?? 0) + (margin.value ?? 0) * 2;
    }
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createElementBlock("svg", {
        height: _ctx.size,
        width: _ctx.size,
        viewBox: `0 0 ${numCells()} ${numCells()}`,
        class: vue.normalizeClass(props.class ?? props.className)
      }, [
        !!_ctx.title ? (vue.openBlock(), vue.createElementBlock("title", _hoisted_2, vue.toDisplayString(_ctx.title), 1)) : vue.createCommentVNode("", true),
        vue.createElementVNode("path", {
          "shape-rendering": "crispEdges",
          fill: _ctx.bgColor,
          d: `M0,0 h${numCells()}v${numCells()}H0z`
        }, null, 8, _hoisted_3),
        vue.createElementVNode("path", {
          "shape-rendering": "crispEdges",
          fill: _ctx.fgColor,
          d: fgPath.value
        }, null, 8, _hoisted_4),
        available.value && !!_ctx.imageSettings?.src ? (vue.openBlock(), vue.createElementBlock("image", {
          key: 1,
          preserveAspectRatio: "none",
          href: _ctx.imageSettings.src,
          height: calculatedImageSettings.value.h,
          width: calculatedImageSettings.value.w,
          x: calculatedImageSettings.value.x + margin.value,
          y: calculatedImageSettings.value.y + margin.value
        }, null, 8, _hoisted_5)) : vue.createCommentVNode("", true)
      ], 10, _hoisted_1);
    };
  }
});

exports.default = _sfc_main;
