import { defineComponent, ref, onMounted, onUnmounted, openBlock, createElementBlock, normalizeClass, unref, renderSlot, createVNode, withCtx, createTextVNode, toDisplayString } from 'vue';
import clx from 'clsx';
import anime from 'animejs';
import { debounce } from 'lodash';
import _sfc_main$1 from '../stack/stack.vue.js';
import _sfc_main$2 from '../box/box.vue.js';
import _sfc_main$3 from '../text/text.vue.js';
import _sfc_main$4 from '../icon/icon.vue.js';
import { store } from '../../models/store.js';
import { container, shadow } from './reveal.css.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "reveal",
  props: {
    hideThresholdHeight: { default: 500 },
    showMoreLabel: { default: "Show more" },
    showLessLabel: { default: "Show less" },
    fadeBackground: {},
    children: { default: void 0 },
    className: { default: void 0 },
    class: {},
    classList: {},
    forwardedRef: {}
  },
  setup(__props) {
    const props = __props;
    const internalTheme = ref("light");
    const isVisible = ref(false);
    const eleHeight = ref();
    const isVisibleRef = ref();
    const animationRef = ref();
    const elementRef = ref();
    const cleanupRef = ref();
    const resizeListenerRef = ref();
    onMounted(() => {
      internalTheme.value = store.getState().theme;
      cleanupRef.value = store.subscribe((newState, prevState) => {
        internalTheme.value = newState.theme;
      });
      setTimeout(() => {
        if (!elementRef.value) return;
        const TOGGLE_SPACE = 40;
        if (elementRef.value.offsetHeight > props.hideThresholdHeight) {
          resizeListenerRef.value = debounce(() => {
            if (!elementRef.value) return;
            elementRef.value.style.height = "auto";
            eleHeight.value = elementRef.value.offsetHeight + TOGGLE_SPACE;
            elementRef.value.style.height = isVisibleRef.value ? `${eleHeight.value}px` : `${props.hideThresholdHeight}px`;
            updateAnimationRef();
          }, 100);
          window.addEventListener("resize", resizeListenerRef.value);
          setTimeout(() => {
            if (!eleHeight.value) {
              eleHeight.value = elementRef.value.offsetHeight + TOGGLE_SPACE;
            }
            updateAnimationRef();
          }, 100);
        }
      }, 100);
    });
    onUnmounted(() => {
      if (typeof cleanupRef.value === "function") cleanupRef.value();
      if (window) {
        window.removeEventListener("resize", resizeListenerRef.value);
      }
    });
    function toggle() {
      isVisibleRef.value = !isVisible.value;
      isVisible.value = !isVisible.value;
    }
    function updateAnimationRef() {
      animationRef.value = anime({
        targets: elementRef.value,
        height: [props.hideThresholdHeight, eleHeight.value],
        duration: 250,
        direction: `alternate`,
        loop: false,
        autoplay: false,
        easing: `easeInOutSine`
      });
      isVisible.value = false;
    }
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        ref_key: "elementRef",
        ref: elementRef,
        class: normalizeClass(unref(clx)(container, _ctx.className))
      }, [
        renderSlot(_ctx.$slots, "default"),
        createVNode(unref(_sfc_main$1), {
          direction: "vertical",
          attributes: {
            display: !isVisible.value ? "flex" : "none",
            cursor: "pointer",
            position: "absolute",
            bottom: 0,
            left: 0,
            right: 0,
            width: "$full",
            justifyContent: "center",
            alignItems: "flex-end",
            height: "$27"
          }
        }, {
          default: withCtx(() => [
            createVNode(unref(_sfc_main$2), {
              height: "$23",
              flexShrink: "0",
              width: "$full",
              class: normalizeClass(shadow[internalTheme.value])
            }, null, 8, ["class"]),
            createVNode(unref(_sfc_main$2), {
              width: "$full",
              display: "flex",
              alignItems: "center",
              justifyContent: "center",
              flex: "1",
              backgroundColor: internalTheme.value === "light" ? "$white" : "$gray900",
              attributes: {
                onClick: () => {
                  toggle();
                  animationRef.value?.play();
                },
                "data-part-id": "reveal-showmore"
              }
            }, {
              default: withCtx(() => [
                createVNode(unref(_sfc_main$3), {
                  color: "$textSecondary",
                  fontWeight: "$semibold",
                  attributes: {
                    marginRight: "$5"
                  }
                }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString(_ctx.showMoreLabel), 1)
                  ]),
                  _: 1
                }),
                createVNode(unref(_sfc_main$4), {
                  name: "arrowDownS",
                  color: "$textSecondary"
                })
              ]),
              _: 1
            }, 8, ["backgroundColor", "attributes"])
          ]),
          _: 1
        }, 8, ["attributes"]),
        createVNode(unref(_sfc_main$1), {
          attributes: {
            display: !!isVisible.value ? "flex" : "none",
            cursor: "pointer",
            position: "absolute",
            bottom: 0,
            width: "100%",
            justifyContent: "center",
            alignItems: "flex-end",
            height: "fit-content"
          }
        }, {
          default: withCtx(() => [
            createVNode(unref(_sfc_main$2), {
              display: "flex",
              alignItems: "center",
              attributes: {
                onClick: () => {
                  toggle();
                  animationRef.value?.reverse();
                  animationRef.value?.play();
                },
                "data-part-id": "reveal-showless"
              }
            }, {
              default: withCtx(() => [
                createVNode(unref(_sfc_main$3), {
                  color: "$textSecondary",
                  fontWeight: "$semibold",
                  attributes: {
                    marginRight: "$5"
                  }
                }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString(_ctx.showLessLabel), 1)
                  ]),
                  _: 1
                }),
                createVNode(unref(_sfc_main$4), {
                  name: "arrowUpS",
                  color: "$textSecondary"
                })
              ]),
              _: 1
            }, 8, ["attributes"])
          ]),
          _: 1
        }, 8, ["attributes"])
      ], 2);
    };
  }
});

export { _sfc_main as default };
