'use strict';

Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

const vue = require('vue');
const clx = require('clsx');
const lodash = require('lodash');
const style = require('../../helpers/style.cjs');
const themes_css = require('../../styles/themes.css.cjs');
const platform = require('../../helpers/platform.cjs');
const store = require('../../models/store.cjs');
const override = require('../../styles/override/override.cjs');

const _hoisted_1 = ["data-is-controlled", "data-interchain-theme-mode"];
const _sfc_main = /* @__PURE__ */ vue.defineComponent({
  __name: "theme-provider",
  props: {
    accent: {},
    defaultTheme: {},
    themeMode: {},
    overrides: {},
    children: {},
    themeDefs: {},
    customTheme: {},
    className: {},
    class: {},
    classList: {},
    forwardedRef: {}
  },
  setup(__props) {
    const props = __props;
    const preferredMode = vue.ref(null);
    const isMounted = vue.ref(false);
    vue.ref(null);
    vue.ref([]);
    const internalTheme = vue.ref("light");
    const UIStore = vue.ref(store.store.getState());
    const cleanupRef = vue.ref();
    vue.onMounted(() => {
      isMounted.value = true;
      const resolvedThemeMode = style.resolveThemeMode(props.defaultTheme);
      if (!isControlled) {
        store.store.getState().setThemeMode(resolvedThemeMode);
      }
      const darkListener = ({ matches }) => {
        if (matches) {
          preferredMode.value = "dark";
        }
      };
      const lightListener = ({ matches }) => {
        if (matches) {
          preferredMode.value = "light";
        }
      };
      const cleanupStore = store.store.subscribe((newState) => {
        UIStore.value = newState;
        internalTheme.value = newState.theme;
      });
      if (darkQuery && lightQuery) {
        if (typeof darkQuery.addEventListener === "function" && typeof lightQuery.addEventListener === "function") {
          darkQuery?.addEventListener("change", darkListener);
          lightQuery?.addEventListener("change", lightListener);
        }
      }
      cleanupRef.value = () => {
        if (typeof darkQuery.removeEventListener === "function") {
          darkQuery?.removeEventListener("change", darkListener);
        }
        if (typeof lightQuery.removeEventListener === "function") {
          lightQuery?.removeEventListener("change", lightListener);
        }
        if (typeof cleanupStore === "function") {
          cleanupStore();
        }
      };
    });
    vue.onUnmounted(() => {
      if (typeof cleanupRef.value === "function") {
        cleanupRef.value();
      }
    });
    const isControlled = vue.computed(() => {
      return props.themeMode != null;
    });
    const isReady = vue.computed(() => {
      return preferredMode.value && isMounted.value;
    });
    const lightQuery = vue.computed(() => {
      if (platform.isSSR()) return null;
      return window?.matchMedia?.(style.mediaQueryColorScheme(`light`));
    });
    const darkQuery = vue.computed(() => {
      if (platform.isSSR()) return null;
      return window?.matchMedia?.(style.mediaQueryColorScheme(`dark`));
    });
    vue.computed(() => {
      return !!darkQuery?.matches;
    });
    vue.computed(() => {
      return !!lightQuery?.matches;
    });
    const themeClass = vue.computed(() => {
      return getNewThemeClass(store.store.getState());
    });
    vue.watch(
      () => [preferredMode.value, internalTheme.value, isReady, UIStore.value],
      () => {
        if (!isReady) {
          return;
        }
        const themeMode = store.store.getState().themeMode;
        const setThemeModeFn = store.store.getState().setThemeMode;
        if (themeMode === "system" || themeMode == null) {
          return setThemeModeFn("system");
        }
      },
      { immediate: true }
    );
    vue.watch(
      () => [props.themeDefs, isControlled],
      () => {
        const finalThemeDefs = props.themeDefs ?? [];
        const isValidThemeDefs = Array.isArray(props.themeDefs) && finalThemeDefs.length > 0;
        if (!isValidThemeDefs) {
          return;
        }
        if (isControlled) {
          return;
        } else {
          if (!lodash.isEqual(store.store.getState().themeDefs, finalThemeDefs)) {
            store.store.getState().setThemeDefs(finalThemeDefs);
          }
        }
      },
      { immediate: true }
    );
    vue.watch(
      () => [props.customTheme],
      () => {
        if (!props.customTheme) return;
        store.store.getState().setCustomTheme(props.customTheme);
      },
      { immediate: true }
    );
    vue.watch(
      () => [props.overrides],
      () => {
        const overrideStyleManager = store.store.getState().overrideStyleManager;
        if (!overrideStyleManager) {
          return;
        }
        overrideStyleManager.update(props.overrides, null);
      },
      { immediate: true }
    );
    vue.watch(
      () => [props.accent],
      () => {
        if (!props.accent) return;
        const prevAccent = UIStore.value.themeAccent;
        const currentColorMode = UIStore.value.theme;
        if (prevAccent !== props.accent) {
          UIStore.value.setThemeAccent(props.accent ?? "blue");
          override.assignThemeVars(
            {
              colors: {
                // @ts-ignore
                accent: style.getAccent(props.accent, currentColorMode ?? "light"),
                // @ts-ignore
                accentText: style.getAccentText(currentColorMode ?? "light")
              }
            },
            currentColorMode
          );
        }
      },
      { immediate: true }
    );
    function getNewThemeClass(uiStore) {
      if (isControlled) {
        if (props.themeMode === "system") {
          const finalThemeMode = isReady ? preferredMode.value : props.themeMode;
          return finalThemeMode === "dark" ? themes_css.darkThemeClass : themes_css.lightThemeClass;
        }
        return props.themeMode === "dark" ? themes_css.darkThemeClass : themes_css.lightThemeClass;
      }
      return uiStore.themeClass;
    }
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createElementBlock("div", {
        "data-is-controlled": isControlled.value,
        "data-interchain-theme-mode": _ctx.themeMode == null ? void 0 : _ctx.themeMode,
        style: vue.normalizeStyle({
          visibility: isMounted.value ? "visible" : "hidden"
        }),
        class: vue.normalizeClass(vue.unref(clx)(themeClass.value, _ctx.className))
      }, [
        vue.renderSlot(_ctx.$slots, "default")
      ], 14, _hoisted_1);
    };
  }
});

exports.default = _sfc_main;
