'use strict';

Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

const vue = require('vue');
const dynamic = require('@vanilla-extract/dynamic');
const clx = require('clsx');
const store = require('../../models/store.cjs');
const icon_vue_vue_type_script_setup_true_lang = require('../icon/icon.vue.cjs');
const toast_constants = require('./toast.constants.cjs');
const toast_css = require('./toast.css.cjs');

const _hoisted_1 = ["aria-live", "data-theme", "data-mounted", "data-promise", "data-removed", "data-visible", "data-y-position", "data-x-position", "data-index", "data-front", "data-swiping", "data-type", "data-invert", "data-swipe-out", "data-expanded"];
const _hoisted_2 = ["data-disabled"];
const _hoisted_3 = /* @__PURE__ */ vue.createElementVNode("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  width: "12",
  height: "12",
  viewBox: "0 0 24 24",
  fill: "none",
  stroke: "currentColor",
  "stroke-width": "1.5",
  "stroke-line-cap": "round",
  "stroke-line-join": "round"
}, [
  /* @__PURE__ */ vue.createElementVNode("line", {
    x1: "18",
    y1: "6",
    x2: "6",
    y2: "18"
  }),
  /* @__PURE__ */ vue.createElementVNode("line", {
    x1: "6",
    y1: "6",
    x2: "18",
    y2: "18"
  })
], -1);
const _hoisted_4 = [
  _hoisted_3
];
const _sfc_main = /* @__PURE__ */ vue.defineComponent({
  __name: "toast",
  props: {
    toast: {},
    toasts: {},
    index: {},
    expanded: { type: Boolean },
    invert: { type: Boolean },
    heights: {},
    setHeights: { type: Function },
    removeToast: { type: Function },
    position: {},
    visibleToasts: {},
    expandByDefault: { type: Boolean },
    closeButton: { type: Boolean },
    interacting: { type: Boolean },
    rawCSS: {},
    duration: {},
    className: {},
    descriptionClassName: {},
    class: {},
    classList: {},
    children: {},
    forwardedRef: {}
  },
  setup(__props) {
    const props = __props;
    const theme = vue.ref("light");
    const mounted = vue.ref(false);
    const removed = vue.ref(false);
    const swiping = vue.ref(false);
    const swipeOut = vue.ref(false);
    const offsetBeforeRemove = vue.ref(0);
    const initialHeight = vue.ref(0);
    const swipeAmount = vue.ref("0px");
    const toastRef = vue.ref();
    const cleanupTimerRef = vue.ref();
    const restoreHeightsRef = vue.ref();
    const closeTimerStartTimeRef = vue.ref();
    const offset = vue.ref();
    const lastCloseTimerStartTimeRef = vue.ref();
    const pointerStartRef = vue.ref();
    const closeTimerRemainingTimeRef = vue.ref();
    const cleanupUIStore = vue.ref();
    vue.onMounted(() => {
      mounted.value = true;
      theme.value = store.store.getState().theme.value;
      cleanupUIStore.value = store.store.subscribe((newState) => {
        theme.value = newState.theme.value;
      });
    });
    vue.onUnmounted(() => {
      if (typeof cleanupTimerRef.value === "function") {
        cleanupTimerRef.value();
      }
      if (typeof restoreHeightsRef.value === "function") {
        restoreHeightsRef.value();
      }
      if (typeof cleanupUIStore.value === "function") {
        cleanupUIStore.value();
      }
    });
    const isFront = vue.computed(() => {
      return props.index === 0;
    });
    const isVisible = vue.computed(() => {
      return props.index + 1 <= props.visibleToasts;
    });
    const toastType = vue.computed(() => {
      return props.toast.type;
    });
    const positionTuple = vue.computed(() => {
      const [y, x] = props.position.split("-");
      return {
        x,
        y
      };
    });
    const invert = vue.computed(() => {
      return props.toast.invert || props.invert;
    });
    const disabled = vue.computed(() => {
      return props.toast.type === "loading";
    });
    const statusIconName = vue.computed(() => {
      if (props.toast.type === "success") return "checkFill";
      if (props.toast.type === "error") return "errorWarningFill";
      return null;
    });
    const heightIndex = vue.computed(() => {
      return props.heights.findIndex(
        (height) => height.toastId === props.toast.id
      ) || 0;
    });
    vue.computed(() => {
      return props.toast.duration || props.duration || toast_constants.TOAST_LIFETIME;
    });
    const toastsHeightBefore = vue.computed(() => {
      return props.heights.reduce((prev, curr, reducerIndex) => {
        if (reducerIndex >= heightIndex) {
          return prev;
        }
        return prev + curr.height;
      }, 0);
    });
    vue.onUpdated(() => {
      offset.value = heightIndex * toast_constants.GAP + toastsHeightBefore;
    });
    vue.watch(
      () => [
        mounted.value,
        props.toast.title,
        props.toast.description,
        props.toast.id
      ],
      () => {
        if (!mounted.value) {
          return;
        }
        const toastNode = toastRef.value;
        const originalHeight = toastNode.style.height;
        toastNode.style.height = "auto";
        const newHeight = toastNode.getBoundingClientRect().height;
        toastNode.style.height = originalHeight;
        initialHeight.value = newHeight;
        const calcNewHeights = () => {
          const oldHeights = props.heights;
          const alreadyExists = oldHeights.find(
            (height) => height.toastId === props.toast.id
          );
          if (!alreadyExists) {
            return [
              {
                toastId: props.toast.id,
                height: newHeight
              },
              ...oldHeights
            ];
          } else {
            return oldHeights.map(
              (height) => height.toastId === props.toast.id ? {
                ...height,
                height: newHeight
              } : height
            );
          }
        };
        props.setHeights(calcNewHeights());
      },
      { immediate: true }
    );
    vue.watch(
      () => [
        props.expanded,
        props.interacting,
        props.expandByDefault,
        props.toast,
        props.duration,
        props.toast.promise,
        deleteToast,
        toastType
      ],
      () => {
        if (typeof cleanupTimerRef.value === "function") {
          cleanupTimerRef.value();
        }
        if (props.toast.promise && toastType === "loading" || props.toast.duration === Infinity) {
          return;
        }
        let timeoutId;
        const pauseTimer = () => {
          if (lastCloseTimerStartTimeRef.value < closeTimerStartTimeRef.value) {
            const elapsedTime = (/* @__PURE__ */ new Date()).getTime() - closeTimerStartTimeRef.value;
            closeTimerRemainingTimeRef.value = closeTimerRemainingTimeRef.value - elapsedTime;
          }
          lastCloseTimerStartTimeRef.value = (/* @__PURE__ */ new Date()).getTime();
        };
        const startTimer = () => {
          closeTimerStartTimeRef.value = (/* @__PURE__ */ new Date()).getTime();
          timeoutId = setTimeout(() => {
            props.toast.onAutoClose?.(props.toast);
            deleteToast();
          }, closeTimerRemainingTimeRef.value);
        };
        if (props.expanded || props.interacting) {
          pauseTimer();
        } else {
          startTimer();
        }
        cleanupTimerRef.value = () => clearTimeout(timeoutId);
      },
      { immediate: true }
    );
    vue.watch(
      () => [props.toast.id],
      () => {
        const toastNode = toastRef.value;
        if (toastNode) {
          const height = toastNode.getBoundingClientRect().height;
          initialHeight.value = height;
          const oldHeights = props.heights;
          props.setHeights([
            {
              toastId: props.toast.id,
              height
            },
            ...oldHeights
          ]);
          restoreHeightsRef.value = () => {
            const oldHeights2 = props.heights;
            props.setHeights(
              oldHeights2.filter((height2) => height2.toastId !== props.toast.id)
            );
          };
        }
      },
      { immediate: true }
    );
    vue.watch(
      () => [props.toast.delete],
      () => {
        if (props.toast.delete) {
          deleteToast();
        }
      },
      { immediate: true }
    );
    function pxToNum(cssValue) {
      return Number(cssValue.replace("px", "")) || 0;
    }
    function deleteToast() {
      removed.value = true;
      offsetBeforeRemove.value = offset.value;
      const oldHeights = props.heights;
      props.setHeights(
        oldHeights.filter((height) => height.toastId !== props.toast.id)
      );
      setTimeout(() => {
        props.removeToast(props.toast);
      }, toast_constants.TIME_BEFORE_UNMOUNT);
    }
    function handleCloseButtonClick() {
      if (disabled) {
        return;
      }
      deleteToast();
      props.toast.onDismiss?.(props.toast);
    }
    function handleCancelButtonClick() {
      deleteToast();
      if (props.toast.cancel?.onClick) {
        props.toast.cancel.onClick();
      }
    }
    function handleActionButtonClick(event) {
      props.toast.action?.onClick(event);
      if (event.defaultPrevented) {
        return;
      }
      deleteToast();
    }
    function handleOnPointerDown(event) {
      if (disabled) return;
      offsetBeforeRemove.value = offset.value;
      event.target.setPointerCapture(event.pointerId);
      if (event.target.tagName === "BUTTON") return;
      swiping.value = true;
      pointerStartRef.value = {
        x: event.clientX,
        y: event.clientY
      };
    }
    function handleOnPointerUp() {
      if (swipeOut.value) {
        return;
      }
      pointerStartRef.value = null;
      const swipeAmountNum = Number(
        pxToNum(toastRef.value?.style.getPropertyValue(`${toast_css.swipeAmountVar}`))
      );
      if (Math.abs(swipeAmountNum) >= toast_constants.SWIPE_TRESHOLD) {
        offsetBeforeRemove.value = offset.value;
        props.toast.onDismiss?.(props.toast);
        deleteToast();
        swipeOut.value = true;
        return;
      }
      swipeAmount.value = "0px";
      swiping.value = false;
    }
    function handleOnPointerMove(event) {
      if (!pointerStartRef.value) return;
      const yPosition = event.clientY - pointerStartRef.value.y;
      const xPosition = event.clientX - pointerStartRef.value.x;
      const clamp = positionTuple.y === "top" ? Math.min : Math.max;
      const clampedY = clamp(0, yPosition);
      const swipeStartThreshold = event.pointerType === "touch" ? 10 : 2;
      const isAllowedToSwipe = Math.abs(clampedY) > swipeStartThreshold;
      if (isAllowedToSwipe) {
        swipeAmount.value = `${yPosition}px`;
      } else if (Math.abs(xPosition) > swipeStartThreshold) {
        pointerStartRef.value = null;
      }
    }
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createElementBlock("li", {
        "aria-atomic": "true",
        role: "status",
        "data-interchain-toast": "",
        "aria-live": vue.unref(toast_css.toast).important ? "assertive" : "polite",
        tabIndex: 0,
        ref_key: "toastRef",
        ref: toastRef,
        "data-styled": true,
        "data-theme": theme.value,
        "data-mounted": mounted.value,
        "data-promise": Boolean(vue.unref(toast_css.toast).promise),
        "data-removed": removed.value,
        "data-visible": isVisible.value,
        "data-y-position": positionTuple.value.y,
        "data-x-position": positionTuple.value.x,
        "data-index": _ctx.index,
        "data-front": isFront.value,
        "data-swiping": swiping.value,
        "data-type": toastType.value,
        "data-invert": invert.value,
        "data-swipe-out": swipeOut.value,
        "data-expanded": Boolean(_ctx.expanded || _ctx.expandByDefault && mounted.value),
        style: vue.normalizeStyle({
          ...vue.unref(dynamic.assignInlineVars)({
            [vue.unref(toast_css.indexVar)]: `${_ctx.index}`,
            [vue.unref(toast_css.toastsBeforeVar)]: `${_ctx.index}`,
            [vue.unref(toast_css.zIndexVar)]: `${_ctx.toasts.length - _ctx.index}`,
            [vue.unref(toast_css.offsetVar)]: `${removed.value ? offsetBeforeRemove.value : offset.value}px`,
            [vue.unref(toast_css.initialHeightVar)]: _ctx.expandByDefault ? "auto" : `${initialHeight.value}px`,
            [vue.unref(toast_css.swipeAmountVar)]: `${swipeAmount.value}`
          }),
          ..._ctx.rawCSS,
          ...vue.unref(toast_css.toast).rawCSS
        }),
        onPointerdown: handleOnPointerDown,
        onPointerup: handleOnPointerUp,
        onPointermove: handleOnPointerMove,
        class: vue.normalizeClass(vue.unref(clx)(vue.unref(toast_css.toast), props.class ?? props.className, vue.unref(toast_css.toast).className))
      }, [
        _ctx.closeButton ? (vue.openBlock(), vue.createElementBlock("button", {
          key: 0,
          "aria-label": "Close toast",
          "data-disabled": disabled.value,
          "data-close-button": true,
          onClick: _cache[0] || (_cache[0] = ($event) => handleCloseButtonClick()),
          class: vue.normalizeClass(vue.unref(toast_css.toastCloseButton))
        }, _hoisted_4, 10, _hoisted_2)) : vue.createCommentVNode("", true),
        toastType.value || vue.unref(toast_css.toast).icon || vue.unref(toast_css.toast).promise ? (vue.openBlock(), vue.createElementBlock("div", {
          key: 1,
          "data-icon": "",
          class: vue.normalizeClass(vue.unref(toast_css.toastIcon))
        }, [
          vue.unref(toast_css.toast).promise && toastType.value === "loading" ? (vue.openBlock(), vue.createElementBlock("div", {
            key: 0,
            class: vue.normalizeClass(vue.unref(toast_css.toastSpinner))
          }, [
            vue.createVNode(vue.unref(icon_vue_vue_type_script_setup_true_lang.default), { name: "loaderFill" })
          ], 2)) : vue.createCommentVNode("", true),
          vue.unref(toast_css.toast).icon ? (vue.openBlock(), vue.createElementBlock(vue.Fragment, { key: 1 }, [
            vue.createTextVNode(vue.toDisplayString(vue.unref(toast_css.toast).icon), 1)
          ], 64)) : vue.createCommentVNode("", true),
          !vue.unref(toast_css.toast).icon && statusIconName.value ? (vue.openBlock(), vue.createBlock(vue.unref(icon_vue_vue_type_script_setup_true_lang.default), {
            key: 2,
            name: statusIconName.value
          }, null, 8, ["name"])) : vue.createCommentVNode("", true)
        ], 2)) : vue.createCommentVNode("", true),
        vue.createElementVNode("div", {
          "data-content": "",
          class: vue.normalizeClass(vue.unref(toast_css.toastContent))
        }, [
          vue.createElementVNode("div", {
            "data-title": "",
            class: vue.normalizeClass(vue.unref(toast_css.toastTitle))
          }, vue.toDisplayString(vue.unref(toast_css.toast).title), 3),
          vue.unref(toast_css.toast).description ? (vue.openBlock(), vue.createElementBlock("div", {
            key: 0,
            "data-description": "",
            class: vue.normalizeClass(vue.unref(clx)(vue.unref(toast_css.toastDescription), _ctx.descriptionClassName))
          }, vue.toDisplayString(vue.unref(toast_css.toast).description), 3)) : vue.createCommentVNode("", true)
        ], 2),
        vue.unref(toast_css.toast).cancel ? (vue.openBlock(), vue.createElementBlock("button", {
          key: 2,
          "data-button": true,
          "data-cancel": true,
          onClick: _cache[1] || (_cache[1] = ($event) => handleCancelButtonClick()),
          class: vue.normalizeClass(vue.unref(toast_css.toastCancelButton))
        }, vue.toDisplayString(vue.unref(toast_css.toast).cancel.label), 3)) : vue.createCommentVNode("", true),
        vue.unref(toast_css.toast).action ? (vue.openBlock(), vue.createElementBlock("button", {
          key: 3,
          "data-button": "",
          onClick: _cache[2] || (_cache[2] = ($event) => handleActionButtonClick($event)),
          class: vue.normalizeClass(vue.unref(toast_css.toastButton))
        }, vue.toDisplayString(vue.unref(toast_css.toast).action.label), 3)) : vue.createCommentVNode("", true)
      ], 46, _hoisted_1);
    };
  }
});

exports.default = _sfc_main;
