import { defineComponent, ref, onMounted, watch, openBlock, createElementBlock, Fragment, createVNode, unref, withCtx, renderSlot, normalizeClass, createTextVNode, toDisplayString } from 'vue';
import { computePosition, inline, offset, flip, shift, arrow, size } from '@floating-ui/dom';
import _sfc_main$1 from '../box/box.vue.js';
import { standardTransitionProperties } from '../shared/shared.css.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "tooltip",
  props: {
    title: { default: void 0 },
    placement: { default: "top" },
    offset: { default: void 0 },
    surroundPadding: { default: void 0 },
    children: { default: void 0 },
    className: {},
    class: {},
    classList: {},
    forwardedRef: {}
  },
  setup(__props) {
    const props = __props;
    const isMounted = ref(false);
    const isShown = ref(false);
    const anchorRef = ref();
    const tooltipRef = ref();
    const arrowRef = ref();
    onMounted(() => {
      isMounted.value = true;
    });
    watch(
      () => [
        isMounted.value,
        isShown.value,
        props.placement,
        props.offset,
        props.surroundPadding
      ],
      () => {
        if (!isMounted.value) {
          return;
        }
        compute();
      },
      { immediate: true }
    );
    function setTooltip(shouldShow) {
      if (shouldShow) {
        isShown.value = true;
        compute();
      } else {
        isShown.value = false;
      }
    }
    function getLatestRefs() {
      return {
        arrow: arrowRef.value,
        anchor: anchorRef.value,
        tooltip: tooltipRef.value
      };
    }
    function compute() {
      const latestRefs = getLatestRefs();
      if (latestRefs.anchor == null || latestRefs.tooltip == null) {
        return;
      }
      computePosition(latestRefs.anchor, latestRefs.tooltip, {
        placement: props.placement ?? "top-start",
        middleware: [
          inline(),
          offset(props.offset ?? 12),
          flip(),
          shift({
            padding: props.surroundPadding ?? 4
          }),
          arrow({
            element: arrowRef.value
          }),
          size({
            apply({ availableWidth, availableHeight, elements }) {
              Object.assign(elements.floating.style, {
                maxWidth: `${availableWidth}px`,
                maxHeight: `${availableHeight}px`
              });
            }
          })
        ]
      }).then((result) => {
        const x = result.x;
        const y = result.y;
        const placement = result.placement;
        const arrowData = result.middlewareData.arrow;
        const { x: arrowX, y: arrowY } = arrowData;
        Object.assign(latestRefs.tooltip.style, {
          left: `${x}px`,
          top: `${y}px`
        });
        const staticSide = {
          top: "bottom",
          right: "left",
          bottom: "top",
          left: "right"
        }[placement.split("-")[0]];
        const endSide = {
          start: "start",
          end: "end"
        }[placement.split("-")[1]];
        const deltaX = endSide === "start" ? -12 : endSide === "end" ? 12 : 0;
        Object.assign(latestRefs.arrow.style, {
          left: arrowX != null ? `${arrowX + deltaX}px` : "",
          top: arrowY != null ? `${arrowY}px` : "",
          right: "",
          bottom: "",
          [staticSide]: "-4px"
        });
      });
    }
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment, null, [
        createVNode(unref(_sfc_main$1), { attributes: {
          "data-part-id": "tooltip-container"
        } }, {
          default: withCtx(() => [
            createVNode(unref(_sfc_main$1), {
              display: "flex",
              alignItems: "center",
              cursor: "help",
              boxRef: anchorRef.value,
              attributes: {
                tabIndex: "0",
                onMouseEnter: () => setTooltip(true),
                onMouseLeave: () => setTooltip(false),
                onFocus: () => setTooltip(true),
                onBlur: () => setTooltip(false)
              }
            }, {
              default: withCtx(() => [
                renderSlot(_ctx.$slots, "default")
              ]),
              _: 3
            }, 8, ["boxRef", "attributes"])
          ]),
          _: 3
        }),
        createVNode(unref(_sfc_main$1), {
          px: "$5",
          py: "$3",
          backgroundColor: "$text",
          borderRadius: "$md",
          position: "absolute",
          width: "max-content",
          zIndex: "1",
          attributes: {
            role: "tooltip"
          },
          display: isShown.value ? "block" : "none",
          boxRef: tooltipRef.value,
          rawCSS: {
            left: "0",
            top: "0"
          },
          class: normalizeClass(unref(standardTransitionProperties))
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString(_ctx.title), 1),
            createVNode(unref(_sfc_main$1), {
              position: "absolute",
              transform: "rotate(45deg)",
              width: "$5",
              height: "$5",
              backgroundColor: "$text",
              boxRef: arrowRef.value,
              attributes: {
                "data-part-id": "tooltip-arrow"
              }
            }, null, 8, ["boxRef"])
          ]),
          _: 1
        }, 8, ["display", "boxRef", "class"])
      ], 64);
    };
  }
});

export { _sfc_main as default };
